# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_DEFACE_METADATA = Metadata(
    id="3c5f529687f2b3d58e2f151ffcd47a04e323d8ea.boutiques",
    name="mri_deface",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriDefaceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_deface(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    defaced_output_file: OutputPathType
    """The resulting defaced MRI volume."""


def mri_deface(
    input_volume: InputPathType,
    brain_template: InputPathType,
    face_template: InputPathType,
    output_volume: str,
    runner: Runner | None = None,
) -> MriDefaceOutputs:
    """
    MRI Deface utility for removing facial features from MRI images.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: The input volume to be defaced (e.g. anatomical MRI\
            image).
        brain_template: Template volume of the brain to be used for defacing.
        face_template: Template volume of the face to be used for defacing.
        output_volume: The output volume path for the defaced image.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriDefaceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_DEFACE_METADATA)
    cargs = []
    cargs.append("mri_deface")
    cargs.append(execution.input_file(input_volume))
    cargs.append(execution.input_file(brain_template))
    cargs.append(execution.input_file(face_template))
    cargs.append(output_volume)
    ret = MriDefaceOutputs(
        root=execution.output_file("."),
        defaced_output_file=execution.output_file(output_volume),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_DEFACE_METADATA",
    "MriDefaceOutputs",
    "mri_deface",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LTA_CONVERT_METADATA = Metadata(
    id="daaa6767af53c23e0e3f62c31924d12dbc6e0eaa.boutiques",
    name="lta_convert",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class LtaConvertOutputs(typing.NamedTuple):
    """
    Output object returned when calling `lta_convert(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_transform_file: OutputPathType | None
    """Output transformed file."""


def lta_convert(
    in_vox: InputPathType | None = None,
    out_vox: str | None = None,
    invert: bool = False,
    ltavox2vox: bool = False,
    ltatkreg: bool = False,
    src_geometry: InputPathType | None = None,
    trg_geometry: InputPathType | None = None,
    trg_conform: bool = False,
    subject_name: str | None = None,
    runner: Runner | None = None,
) -> LtaConvertOutputs:
    """
    This program converts between different linear transform formats.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        in_vox: Input transform in source image space (inverse VOX2VOX).
        out_vox: Output transform in source image space (inverse VOX2VOX).
        invert: Inverts transform.
        ltavox2vox: Output type VOX2VOX (default RAS2RAS) with --ltaout.
        ltatkreg: Output type REGISTER_DAT (default RAS2RAS) with --ltaout.
        src_geometry: Specify src image geometry (mov volume for\
            TKREG/register.dat).
        trg_geometry: Specify trg image geometry.
        trg_conform: Conform trg image geometry (COR standard).
        subject_name: Specify subject name (overrides if input has subject name\
            defined).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LtaConvertOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LTA_CONVERT_METADATA)
    cargs = []
    cargs.append("lta_convert")
    if in_vox is not None:
        cargs.extend([
            "--invox",
            execution.input_file(in_vox)
        ])
    if out_vox is not None:
        cargs.extend([
            "--outvox",
            out_vox
        ])
    if invert:
        cargs.append("--invert")
    if ltavox2vox:
        cargs.append("--ltavox2vox")
    if ltatkreg:
        cargs.append("--ltatkreg")
    if src_geometry is not None:
        cargs.extend([
            "--src",
            execution.input_file(src_geometry)
        ])
    if trg_geometry is not None:
        cargs.extend([
            "--trg",
            execution.input_file(trg_geometry)
        ])
    if trg_conform:
        cargs.append("--trgconform")
    if subject_name is not None:
        cargs.extend([
            "--subject",
            subject_name
        ])
    ret = LtaConvertOutputs(
        root=execution.output_file("."),
        output_transform_file=execution.output_file(out_vox) if (out_vox is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LTA_CONVERT_METADATA",
    "LtaConvertOutputs",
    "lta_convert",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SH2POWER_METADATA = Metadata(
    id="536779908dfe6a15e2ec1a07b45bd1fe2e688ccd.boutiques",
    name="sh2power",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class Sh2powerConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class Sh2powerOutputs(typing.NamedTuple):
    """
    Output object returned when calling `sh2power(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    power: OutputPathType
    """the output power image."""


def sh2power(
    sh: InputPathType,
    power: str,
    spectrum: bool = False,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[Sh2powerConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> Sh2powerOutputs:
    """
    Compute the total power of a spherical harmonics image.
    
    This command computes the sum of squared SH coefficients, which equals the
    mean-squared amplitude of the spherical function it represents.
    
    The spherical harmonic coefficients are stored according the conventions
    described the main documentation, which can be found at the following link:
    https://mrtrix.readthedocs.io/en/3.0.4/concepts/spherical_harmonics.html
    
    References:
    
    .
    
    Author: MRTrix3 Developers
    
    URL: https://www.mrtrix.org/
    
    Args:
        sh: the input spherical harmonics coefficients image.
        power: the output power image.
        spectrum: output the power spectrum, i.e., the power contained within\
            each harmonic degree (l=0, 2, 4, ...) as a 4-D image.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Sh2powerOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SH2POWER_METADATA)
    cargs = []
    cargs.append("sh2power")
    if spectrum:
        cargs.append("-spectrum")
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(sh))
    cargs.append(power)
    ret = Sh2powerOutputs(
        root=execution.output_file("."),
        power=execution.output_file(power),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SH2POWER_METADATA",
    "Sh2powerConfig",
    "Sh2powerOutputs",
    "sh2power",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURFACE_APPLY_WARPFIELD_METADATA = Metadata(
    id="62d776ef4770f80788d15439d0c09cdb0b85568a.boutiques",
    name="surface-apply-warpfield",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class SurfaceApplyWarpfieldOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surface_apply_warpfield(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_surf: OutputPathType
    """the output transformed surface"""


def surface_apply_warpfield(
    in_surf: InputPathType,
    warpfield: str,
    out_surf: str,
    opt_fnirt_forward_warp: str | None = None,
    runner: Runner | None = None,
) -> SurfaceApplyWarpfieldOutputs:
    """
    Apply warpfield to surface file.
    
    NOTE: warping a surface requires the INVERSE of the warpfield used to warp
    the volume it lines up with. The header of the forward warp is needed by the
    -fnirt option in order to correctly interpret the displacements in the fnirt
    warpfield.
    
    If the -fnirt option is not present, the warpfield must be a nifti 'world'
    warpfield, which can be obtained with the -convert-warpfield command.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        in_surf: the surface to transform.
        warpfield: the INVERSE warpfield.
        out_surf: the output transformed surface.
        opt_fnirt_forward_warp: MUST be used if using a fnirt warpfield: the\
            forward warpfield.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceApplyWarpfieldOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_APPLY_WARPFIELD_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-apply-warpfield")
    cargs.append(execution.input_file(in_surf))
    cargs.append(warpfield)
    cargs.append(out_surf)
    if opt_fnirt_forward_warp is not None:
        cargs.extend([
            "-fnirt",
            opt_fnirt_forward_warp
        ])
    ret = SurfaceApplyWarpfieldOutputs(
        root=execution.output_file("."),
        out_surf=execution.output_file(out_surf),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURFACE_APPLY_WARPFIELD_METADATA",
    "SurfaceApplyWarpfieldOutputs",
    "surface_apply_warpfield",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MEDIANFILTER_METADATA = Metadata(
    id="dad8d29bb39aa0253a34873e5359f391f56a7824.boutiques",
    name="medianfilter",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class MedianfilterOutputs(typing.NamedTuple):
    """
    Output object returned when calling `medianfilter(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    filtered_file: OutputPathType
    """Output file containing the median filtered image"""


def medianfilter(
    infile: InputPathType,
    outfile: InputPathType,
    runner: Runner | None = None,
) -> MedianfilterOutputs:
    """
    A tool to perform 26 neighbourhood median filtering on an input image.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        infile: Input image file to be filtered (e.g., img.nii.gz).
        outfile: Output file to store the filtered image (e.g.,\
            img_filtered.nii.gz).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MedianfilterOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MEDIANFILTER_METADATA)
    cargs = []
    cargs.append("medianfilter")
    cargs.append(execution.input_file(infile))
    cargs.append(execution.input_file(outfile))
    ret = MedianfilterOutputs(
        root=execution.output_file("."),
        filtered_file=execution.output_file(pathlib.Path(outfile).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MEDIANFILTER_METADATA",
    "MedianfilterOutputs",
    "medianfilter",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MAP_ALL_LABELS_LH_METADATA = Metadata(
    id="569f8a45a5f0082dff949fe6bc883e667d21393b.boutiques",
    name="map_all_labels-lh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MapAllLabelsLhOutputs(typing.NamedTuple):
    """
    Output object returned when calling `map_all_labels_lh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output file generated after processing."""


def map_all_labels_lh(
    which: str,
    fname: str,
    hemi: str,
    spherical_surf: InputPathType,
    output: str,
    runner: Runner | None = None,
) -> MapAllLabelsLhOutputs:
    """
    Paints output onto a subject's left hemisphere using FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        which: Which type of data to process. Options are: coords, label, vals,\
            curv, area.
        fname: The file name to process.
        hemi: The hemisphere to process (usually 'lh' for left hemisphere).
        spherical_surf: The spherical surface file.
        output: Output file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MapAllLabelsLhOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MAP_ALL_LABELS_LH_METADATA)
    cargs = []
    cargs.extend([
        "-lh",
        "map_all_labels" + which
    ])
    cargs.append(fname)
    cargs.append(hemi)
    cargs.append(execution.input_file(spherical_surf))
    cargs.append("[SUBJECTS...]")
    cargs.append(output)
    ret = MapAllLabelsLhOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MAP_ALL_LABELS_LH_METADATA",
    "MapAllLabelsLhOutputs",
    "map_all_labels_lh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MAKE_EXVIVO_FILLED_METADATA = Metadata(
    id="ea9e6e6bb03c9eb7e7861ad8386b4df6348f9898.boutiques",
    name="make_exvivo_filled",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MakeExvivoFilledOutputs(typing.NamedTuple):
    """
    Output object returned when calling `make_exvivo_filled(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def make_exvivo_filled(
    subject_name: str,
    input_samseg: InputPathType,
    input_intensity_vol: InputPathType,
    hemi_both: str,
    runner: Runner | None = None,
) -> MakeExvivoFilledOutputs:
    """
    A command-line tool for generating filled ex vivo brain images.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_name: Name of the subject.
        input_samseg: Input SAMSEG (Segmentation Analysis of MRI brain images).
        input_intensity_vol: Input intensity volume.
        hemi_both: Specify hemisphere or both.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MakeExvivoFilledOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MAKE_EXVIVO_FILLED_METADATA)
    cargs = []
    cargs.append("make_exvivo_filled")
    cargs.append(subject_name)
    cargs.append(execution.input_file(input_samseg))
    cargs.append(execution.input_file(input_intensity_vol))
    cargs.append(hemi_both)
    ret = MakeExvivoFilledOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MAKE_EXVIVO_FILLED_METADATA",
    "MakeExvivoFilledOutputs",
    "make_exvivo_filled",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_ALIGN_LONG_CSH_METADATA = Metadata(
    id="727dcf17137017559789f10344fd699c98eab6e5.boutiques",
    name="mri_align_long.csh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriAlignLongCshOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_align_long_csh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    aligned_norm: OutputPathType
    """Aligned norm volume in base space"""
    aligned_aseg: OutputPathType
    """Aligned aseg volume in base space"""


def mri_align_long_csh(
    base_id: str,
    runner: Runner | None = None,
) -> MriAlignLongCshOutputs:
    """
    Aligns all longitudinal norm and aseg files to the base space in FreeSurfer
    processing.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        base_id: Identifier for the base subject.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriAlignLongCshOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_ALIGN_LONG_CSH_METADATA)
    cargs = []
    cargs.append("mri_align_long.csh")
    cargs.append(base_id)
    ret = MriAlignLongCshOutputs(
        root=execution.output_file("."),
        aligned_norm=execution.output_file("[base_id].long.base/mri/norm-base.mgz"),
        aligned_aseg=execution.output_file("[base_id].long.base/mri/aseg.base.mgz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_ALIGN_LONG_CSH_METADATA",
    "MriAlignLongCshOutputs",
    "mri_align_long_csh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GTMSEG_METADATA = Metadata(
    id="29e1c1370e446a18137bbf4e9561c7972ac57725.boutiques",
    name="gtmseg",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class GtmsegOutputs(typing.NamedTuple):
    """
    Output object returned when calling `gtmseg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_volume: OutputPathType | None
    """Output segmentation volume"""
    output_ctab: OutputPathType
    """Generated color table for the output segmentation"""


def gtmseg(
    subject: str,
    outvol: str | None = "gtmseg.mgz",
    usf: float | None = 2,
    subsegwm: bool = False,
    keep_hypo: bool = False,
    keep_cc: bool = False,
    dmax: float | None = 5,
    ctx_annot: str | None = "aparc 1000 2000",
    wm_annot: str | None = "lobes 3200 4200",
    output_usf: float | None = None,
    head: str | None = None,
    subseg_cbwm: bool = False,
    no_pons: bool = False,
    no_vermis: bool = False,
    ctab: InputPathType | None = None,
    no_seg_stats: bool = False,
    xcerseg: bool = False,
    debug: bool = False,
    runner: Runner | None = None,
) -> GtmsegOutputs:
    """
    Creates an anatomical segmentation for the geometric transfer matrix (GTM) used
    in PET partial volume correction.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: Subject to analyze.
        outvol: Output volume relative to subject/mri.
        usf: Upsampling factor for segmentation resolution.
        subsegwm: Subsegment white matter into lobes.
        keep_hypo: Do not relabel hypointensities as white matter when\
            subsegmenting WM.
        keep_cc: Do not relabel corpus callosum as white matter.
        dmax: Distance threshold for subsegmenting WM.
        ctx_annot: Annotation for cortical segmentation.
        wm_annot: Annotation for WM segmentation with --subsegwm.
        output_usf: Set output upsampling factor different from input USF for\
            debugging.
        head: Use alternative head segmentation file.
        subseg_cbwm: Subsegment cerebellum WM into core and gyri.
        no_pons: Do not add pons segmentation when running xcerebralseg.
        no_vermis: Do not add vermis segmentation when running xcerebralseg.
        ctab: Color table for custom segmentation.
        no_seg_stats: Do not compute segmentation statistics.
        xcerseg: Run xcerebralseg to create apas+head.mgz.
        debug: Enable debugging mode.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GtmsegOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GTMSEG_METADATA)
    cargs = []
    cargs.append("gtmseg")
    cargs.extend([
        "--s",
        subject
    ])
    if outvol is not None:
        cargs.extend([
            "--o",
            outvol
        ])
    if usf is not None:
        cargs.extend([
            "--usf",
            str(usf)
        ])
    if subsegwm:
        cargs.append("--subsegwm")
    if keep_hypo:
        cargs.append("--keep-hypo")
    if keep_cc:
        cargs.append("--keep-cc")
    if dmax is not None:
        cargs.extend([
            "--dmax",
            str(dmax)
        ])
    if ctx_annot is not None:
        cargs.extend([
            "--ctx-annot",
            ctx_annot
        ])
    if wm_annot is not None:
        cargs.extend([
            "--wm-annot",
            wm_annot
        ])
    if output_usf is not None:
        cargs.extend([
            "--output-usf",
            str(output_usf)
        ])
    if head is not None:
        cargs.extend([
            "--head",
            head
        ])
    if subseg_cbwm:
        cargs.append("--subseg-cblum-wm")
    if no_pons:
        cargs.append("--no-pons")
    if no_vermis:
        cargs.append("--no-vermis")
    if ctab is not None:
        cargs.extend([
            "--ctab",
            execution.input_file(ctab)
        ])
    if no_seg_stats:
        cargs.append("--no-seg-stats")
    if xcerseg:
        cargs.append("--xcerseg")
    if debug:
        cargs.append("--debug")
    ret = GtmsegOutputs(
        root=execution.output_file("."),
        output_volume=execution.output_file("$SUBJECTS_DIR/" + subject + "/mri/" + outvol) if (outvol is not None) else None,
        output_ctab=execution.output_file("$SUBJECTS_DIR/" + subject + "/mri/gtmseg+myseg.ctab"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GTMSEG_METADATA",
    "GtmsegOutputs",
    "gtmseg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_OR_METADATA = Metadata(
    id="23de8af32e672952c619b947417102b41f7a6636.boutiques",
    name="mri_or",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriOrOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_or(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_or(
    input_files: list[InputPathType],
    original_labels: bool = False,
    runner: Runner | None = None,
) -> MriOrOutputs:
    """
    Performs a logical voxel-wise OR on a series of volumes.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_files: Input image files on which to perform the logical OR\
            operation.
        original_labels: Keeps the original label values in the input files\
            when creating the output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriOrOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_OR_METADATA)
    cargs = []
    cargs.append("mri_or")
    if original_labels:
        cargs.append("-o")
    cargs.extend([execution.input_file(f) for f in input_files])
    ret = MriOrOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_OR_METADATA",
    "MriOrOutputs",
    "mri_or",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_WATERSHED_METADATA = Metadata(
    id="1390c3e2e9ad7d6fa430f8cfd5c3863c2de5ce50.boutiques",
    name="mri_watershed",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriWatershedOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_watershed(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_brain_vol: OutputPathType
    """Skull stripped brain volume"""
    output_brain_surf: OutputPathType | None
    """Saved brain surface when specified"""


def mri_watershed(
    input_volume: InputPathType,
    output_volume: str,
    weight: float | None = None,
    no_wta_flag: bool = False,
    proba_merging: float | None = None,
    preflooding_height: float | None = None,
    no_seedpt_flag: bool = False,
    no_ta_flag: bool = False,
    copy_flag: bool = False,
    atlas_flag: bool = False,
    surf_name: str | None = None,
    usesurf_ras_flag: bool = False,
    no_t1_analysis_flag: bool = False,
    shrink_surface_flag: bool = False,
    expand_surface_flag: bool = False,
    use_watershed_flag: bool = False,
    t1_volume: InputPathType | None = None,
    wat_temp_flag: bool = False,
    first_temp_flag: bool = False,
    surf_debug_flag: bool = False,
    brain_surf_name: str | None = None,
    shrink_brain_surf: str | None = None,
    seed_point: list[float] | None = None,
    center_brain: list[float] | None = None,
    brain_radius: float | None = None,
    watershed_threshold: float | None = None,
    no_watershed_analysis_flag: bool = False,
    label_flag: bool = False,
    manual_params: list[float] | None = None,
    xthresh: float | None = None,
    mask_flag: bool = False,
    runner: Runner | None = None,
) -> MriWatershedOutputs:
    """
    A tool for stripping skull and other non-brain tissues to produce brain volume
    from T1 volume.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: Input volume (e.g., T1 volume).
        output_volume: Output volume (e.g., skull stripped brain volume).
        weight: Preweight the input image using atlas information.
        no_wta_flag: Don't use the preweighting for the template deformation.
        proba_merging: Use the basins merging using atlas information.
        preflooding_height: Pre-size the preflooding height (in percent).
        no_seedpt_flag: Don't use seedpoints using atlas information.
        no_ta_flag: Don't use template deformation using atlas information.
        copy_flag: Just copy input to output, ignore other options.
        atlas_flag: Use the atlas information to correct the segmentation.
        surf_name: Save the BEM surfaces; use consistent coordinates with\
            tkmedit.
        usesurf_ras_flag: Use the surface RAS coordinates for surfaces.
        no_t1_analysis_flag: Don't do T1 analysis, useful when running out of\
            memory.
        shrink_surface_flag: Shrink the surface.
        expand_surface_flag: Expand the surface.
        use_watershed_flag: Use only the watershed algorithm.
        t1_volume: Specify T1 input volume.
        wat_temp_flag: Use watershed algorithm and first template smoothing.
        first_temp_flag: Use only the first template smoothing + local matching.
        surf_debug_flag: Visualize the surfaces onto the output volume.
        brain_surf_name: Save the brain surface.
        shrink_brain_surf: Save the brain surface shrank inward by a specified\
            mm.
        seed_point: Add a seed point as a 3D coordinate.
        center_brain: Specify the center of the brain (voxel coordinates).
        brain_radius: Specify the radius of the brain (voxel units).
        watershed_threshold: Change the threshold in the watershed process.
        no_watershed_analysis_flag: Don't use the watershed analysis process.
        label_flag: Labelize the output volume into scalp, skull, csf, gray,\
            and white matter.
        manual_params: Change parameters csf_max, transition intensity, and\
            GM_intensity.
        xthresh: Remove voxels whose intensity exceeds the specified threshold.
        mask_flag: Mask a volume with the brain mask.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriWatershedOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_WATERSHED_METADATA)
    cargs = []
    cargs.append("mri_watershed")
    cargs.append(execution.input_file(input_volume))
    cargs.append(output_volume)
    if weight is not None:
        cargs.extend([
            "-w",
            str(weight)
        ])
    if no_wta_flag:
        cargs.append("-no_wta")
    if proba_merging is not None:
        cargs.extend([
            "-b",
            str(proba_merging)
        ])
    if preflooding_height is not None:
        cargs.extend([
            "-h",
            str(preflooding_height)
        ])
    if no_seedpt_flag:
        cargs.append("-no_seedpt")
    if no_ta_flag:
        cargs.append("-no-ta")
    if copy_flag:
        cargs.append("-copy")
    if atlas_flag:
        cargs.append("-atlas")
    if surf_name is not None:
        cargs.extend([
            "-surf",
            surf_name
        ])
    if usesurf_ras_flag:
        cargs.append("-useSRAS")
    if no_t1_analysis_flag:
        cargs.append("-noT1")
    if shrink_surface_flag:
        cargs.append("-less")
    if expand_surface_flag:
        cargs.append("-more")
    if use_watershed_flag:
        cargs.append("-wat")
    if t1_volume is not None:
        cargs.extend([
            "-T1",
            execution.input_file(t1_volume)
        ])
    if wat_temp_flag:
        cargs.append("-wat+temp")
    if first_temp_flag:
        cargs.append("-first_temp")
    if surf_debug_flag:
        cargs.append("-surf_debug")
    if brain_surf_name is not None:
        cargs.extend([
            "-brainsurf",
            brain_surf_name
        ])
    if shrink_brain_surf is not None:
        cargs.extend([
            "-shk_br_surf",
            shrink_brain_surf
        ])
    if seed_point is not None:
        cargs.extend([
            "-s",
            *map(str, seed_point)
        ])
    if center_brain is not None:
        cargs.extend([
            "-c",
            *map(str, center_brain)
        ])
    if brain_radius is not None:
        cargs.extend([
            "-r",
            str(brain_radius)
        ])
    if watershed_threshold is not None:
        cargs.extend([
            "-t",
            str(watershed_threshold)
        ])
    if no_watershed_analysis_flag:
        cargs.append("-n")
    if label_flag:
        cargs.append("-LABEL")
    if manual_params is not None:
        cargs.extend([
            "-man",
            *map(str, manual_params)
        ])
    if xthresh is not None:
        cargs.extend([
            "-xthresh",
            str(xthresh)
        ])
    if mask_flag:
        cargs.append("-mask")
    ret = MriWatershedOutputs(
        root=execution.output_file("."),
        output_brain_vol=execution.output_file(output_volume),
        output_brain_surf=execution.output_file(brain_surf_name) if (brain_surf_name is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_WATERSHED_METADATA",
    "MriWatershedOutputs",
    "mri_watershed",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DICOM_HDR_METADATA = Metadata(
    id="f1dd7c5e97c664a21c6f4e09518ffc5513e4e54f.boutiques",
    name="dicom_hdr",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class DicomHdrOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dicom_hdr(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def dicom_hdr(
    files: list[InputPathType],
    hex_: bool = False,
    noname: bool = False,
    sexinfo: bool = False,
    mulfram: bool = False,
    v_dump: float | None = None,
    no_length: bool = False,
    slice_times: bool = False,
    slice_times_verb: bool = False,
    siemens_csa_data: bool = False,
    runner: Runner | None = None,
) -> DicomHdrOutputs:
    """
    A tool to print DICOM file information to stdout.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        files: DICOM file(s) to read.
        hex_: Include hexadecimal printout for integer values.
        noname: Don't include element names in the printout.
        sexinfo: Dump Siemens EXtra INFO text (0029 1020), if present (can be\
            VERY lengthy).
        mulfram: Dump multi-frame information, if present (1 line per frame,\
            plus an XML-style header/footer). This option also implies -noname.
        v_dump: Dump n words of binary data also.
        no_length: Skip lengths and offsets (helps diffs).
        slice_times: Show slice times from Siemens mosaic images.
        slice_times_verb: Show slice times from Siemens mosaic images\
            verbosely. (multiple uses increase verbosity, can dump CSA data).
        siemens_csa_data: Same as 3 -slice_times_verb opts.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DicomHdrOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DICOM_HDR_METADATA)
    cargs = []
    cargs.append("dicom_hdr")
    cargs.extend([execution.input_file(f) for f in files])
    if hex_:
        cargs.append("-hex")
    if noname:
        cargs.append("-noname")
    if sexinfo:
        cargs.append("-sexinfo")
    if mulfram:
        cargs.append("-mulfram")
    if v_dump is not None:
        cargs.extend([
            "-v",
            str(v_dump)
        ])
    if no_length:
        cargs.append("-no_length")
    if slice_times:
        cargs.append("-slice_times")
    if slice_times_verb:
        cargs.append("-slice_times_verb")
    if siemens_csa_data:
        cargs.append("-siemens_csa_data")
    ret = DicomHdrOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DICOM_HDR_METADATA",
    "DicomHdrOutputs",
    "dicom_hdr",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_CA_LABEL_METADATA = Metadata(
    id="2f8449c959553824821e094d83f024564539a65c.boutiques",
    name="mris_ca_label",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisCaLabelOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_ca_label(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    labeled_surface: OutputPathType
    """Labeled cortical surface model"""


def mris_ca_label(
    subject: str,
    hemi: str,
    canonsurf: InputPathType,
    classifier: InputPathType,
    outputfile: str,
    seed: float | None = None,
    sdir: str | None = None,
    orig: str | None = None,
    long_flag: bool = False,
    r: InputPathType | None = None,
    novar_flag: bool = False,
    nbrs: float | None = None,
    f: float | None = None,
    t: InputPathType | None = None,
    p: str | None = None,
    v: float | None = None,
    w: str | None = None,
    help_flag: bool = False,
    version_flag: bool = False,
    runner: Runner | None = None,
) -> MrisCaLabelOutputs:
    """
    Produces an annotation file in which each cortical surface vertex is assigned a
    neuroanatomical label using a previously-prepared atlas file.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: Subject ID for labeling.
        hemi: Hemisphere (rh or lh).
        canonsurf: Name of the spherical surface file that describes the\
            registration of a subject's vertices to the average surface.
        classifier: Specify classifier array input file.
        outputfile: Output annotated surface file listing the region label for\
            each vertex.
        seed: Specify the seed for the random number generator.
        sdir: Specify a subjects directory (default=$SUBJECTS_DIR).
        orig: Specify filename of original surface (default=smoothwm).
        long_flag: Refines the initial labeling read-in from -r (default:\
            disabled).
        r: File containing precomputed parcellation.
        novar_flag: Sets all covariance matrices to the identity (default:\
            disabled).
        nbrs: Neighborhood size (default=2).
        f: Applies mode filter <number> times before writing output\
            (default=10).
        t: Specify parcellation table input file (default: none).
        p: Output file containing label probability for each vertex.
        v: Diagnostic level (default=0).
        w: Writes-out snapshots of gibbs process every <number> iterations to\
            <filename> (default=disabled).
        help_flag: Print help information.
        version_flag: Print version information.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisCaLabelOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_CA_LABEL_METADATA)
    cargs = []
    cargs.append("mris_ca_label")
    cargs.append(subject)
    cargs.append(hemi)
    cargs.append(execution.input_file(canonsurf))
    cargs.append(execution.input_file(classifier))
    cargs.append(outputfile)
    if seed is not None:
        cargs.extend([
            "-seed",
            str(seed)
        ])
    if sdir is not None:
        cargs.extend([
            "-sdir",
            sdir
        ])
    if orig is not None:
        cargs.extend([
            "-orig",
            orig
        ])
    if long_flag:
        cargs.append("-long")
    if r is not None:
        cargs.extend([
            "-r",
            execution.input_file(r)
        ])
    if novar_flag:
        cargs.append("-novar")
    if nbrs is not None:
        cargs.extend([
            "-nbrs",
            str(nbrs)
        ])
    if f is not None:
        cargs.extend([
            "-f",
            str(f)
        ])
    if t is not None:
        cargs.extend([
            "-t",
            execution.input_file(t)
        ])
    if p is not None:
        cargs.extend([
            "-p",
            p
        ])
    if v is not None:
        cargs.extend([
            "-v",
            str(v)
        ])
    if w is not None:
        cargs.extend([
            "-w",
            w
        ])
    if help_flag:
        cargs.append("--help")
    if version_flag:
        cargs.append("--version")
    ret = MrisCaLabelOutputs(
        root=execution.output_file("."),
        labeled_surface=execution.output_file(outputfile),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_CA_LABEL_METADATA",
    "MrisCaLabelOutputs",
    "mris_ca_label",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_ABOVERLAP_METADATA = Metadata(
    id="ce33e10c4b1ac12e30e9f2905df1b25512061469.boutiques",
    name="3dABoverlap",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dAboverlapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_aboverlap(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_3d_aboverlap(
    dataset_a: InputPathType,
    dataset_b: InputPathType,
    no_automask: bool = False,
    quiet: bool = False,
    verbose: bool = False,
    runner: Runner | None = None,
) -> V3dAboverlapOutputs:
    """
    Counts various metrics about how the automasks of datasets A and B overlap or
    don't overlap.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        dataset_a: First input dataset.
        dataset_b: Second input dataset.
        no_automask: Consider input datasets as masks (automask does not work\
            on mask datasets).
        quiet: Be as quiet as possible (without being entirely mute).
        verbose: Print out some progress reports (to stderr).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dAboverlapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_ABOVERLAP_METADATA)
    cargs = []
    cargs.append("3dABoverlap")
    cargs.append(execution.input_file(dataset_a))
    cargs.append(execution.input_file(dataset_b))
    if no_automask:
        cargs.append("-no_automask")
    if quiet:
        cargs.append("-quiet")
    if verbose:
        cargs.append("-verb")
    ret = V3dAboverlapOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dAboverlapOutputs",
    "V_3D_ABOVERLAP_METADATA",
    "v_3d_aboverlap",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ROIGROW_METADATA = Metadata(
    id="12bb44f9721e85ea23d86fcfc727735d33f56b50.boutiques",
    name="ROIgrow",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class RoigrowOutputs(typing.NamedTuple):
    """
    Output object returned when calling `roigrow(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType | None
    """1D output dataset."""


def roigrow(
    input_surface: str,
    roi_labels: str,
    lim_distance: float,
    output_prefix: str | None = None,
    full_list: bool = False,
    grow_from_edge: bool = False,
    insphere_diameter: float | None = None,
    inbox_edges: list[float] | None = None,
    runner: Runner | None = None,
) -> RoigrowOutputs:
    """
    A program to expand an ROI on the surface.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_surface: Specify input surface. You can also use -t* and -spec\
            and -surf methods to input surfaces.
        roi_labels: Data column containing integer labels of ROIs. Each integer\
            label gets grown separately.
        lim_distance: Distance to cover from each node. The units of LIM are\
            those of the surface's node coordinates. Distances are calculated along\
            the surface's mesh.
        output_prefix: Prefix of 1D output dataset. Default is ROIgrow.
        full_list: Output a row for each node on the surface. Nodes not in the\
            grown ROI, receive a 0 for a label. This option is ONLY for use with\
            -roi_labels.
        grow_from_edge: Grow ROIs from their edges rather than the brute force\
            default. This might make the program faster on large ROIs and large\
            surfaces.
        insphere_diameter: Diameter of the sphere inside which nodes are added\
            instead of growing along the surface.
        inbox_edges: Use a box of edge widths E1, E2, E3 instead of DIA.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RoigrowOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ROIGROW_METADATA)
    cargs = []
    cargs.append("ROIgrow")
    cargs.extend([
        "-i_TYPE",
        input_surface
    ])
    cargs.extend([
        "-roi_labels",
        roi_labels
    ])
    cargs.extend([
        "-lim",
        str(lim_distance)
    ])
    if output_prefix is not None:
        cargs.extend([
            "-prefix",
            output_prefix
        ])
    if full_list:
        cargs.append("-full_list")
    if grow_from_edge:
        cargs.append("-grow_from_edge")
    if insphere_diameter is not None:
        cargs.extend([
            "-insphere",
            str(insphere_diameter)
        ])
    if inbox_edges is not None:
        cargs.extend([
            "-inbox",
            *map(str, inbox_edges)
        ])
    ret = RoigrowOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_prefix + ".1D") if (output_prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ROIGROW_METADATA",
    "RoigrowOutputs",
    "roigrow",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_MORPH_STATS_METADATA = Metadata(
    id="099da71ba5e21f2b547c57eee2eaadeb2784a79c.boutiques",
    name="mris_morph_stats",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisMorphStatsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_morph_stats(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    stats_output: OutputPathType
    """Generated statistics of the surface-based deformation field."""


def mris_morph_stats(
    subject_name: str,
    hemisphere: typing.Literal["lh", "rh"],
    morphed_surface: InputPathType,
    output_name: str,
    runner: Runner | None = None,
) -> MrisMorphStatsOutputs:
    """
    This program generates statistics which characterize a surface-based deformation
    field.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_name: Name of the subject.
        hemisphere: Hemisphere, either 'lh' for left hemisphere or 'rh' for\
            right hemisphere.
        morphed_surface: Morphed surface file.
        output_name: Name of the output to be generated.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisMorphStatsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_MORPH_STATS_METADATA)
    cargs = []
    cargs.append("mris_morph_stats")
    cargs.append(subject_name)
    cargs.append(hemisphere)
    cargs.append(execution.input_file(morphed_surface))
    cargs.append(output_name)
    ret = MrisMorphStatsOutputs(
        root=execution.output_file("."),
        stats_output=execution.output_file(output_name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_MORPH_STATS_METADATA",
    "MrisMorphStatsOutputs",
    "mris_morph_stats",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__SUMA_ALIGN_TO_EXPERIMENT_METADATA = Metadata(
    id="8f81484159017f8749f8211125315dcfa8d64e88.boutiques",
    name="@SUMA_AlignToExperiment",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VSumaAlignToExperimentOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__suma_align_to_experiment(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    aligned_volume: OutputPathType | None
    """Output volume after alignment."""
    additional_followers: OutputPathType | None
    """Output followers dataset after transforming."""


def v__suma_align_to_experiment(
    exp_anat: InputPathType,
    surf_anat: InputPathType,
    dxyz: float | None = None,
    out_dxyz: float | None = None,
    wd: bool = False,
    al: bool = False,
    al_opt: str | None = None,
    ok_change_view: bool = False,
    strip_skull: str | None = None,
    skull_strip_opt: str | None = None,
    align_centers: bool = False,
    init_xform: InputPathType | None = None,
    ea_clip_below: float | None = None,
    prefix: str | None = None,
    surf_anat_followers: str | None = None,
    followers_interp: str | None = None,
    atlas_followers: bool = False,
    echo: bool = False,
    keep_tmp: bool = False,
    overwrite_resp: str | None = None,
    runner: Runner | None = None,
) -> VSumaAlignToExperimentOutputs:
    """
    Creates a version of Surface Anatomy that is registered to Experiment Anatomy.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        exp_anat: Name of high resolution anatomical data set in register with\
            experimental data.
        surf_anat: Path and name of high resolution antomical data set used to\
            create the surface.
        dxyz: Optional parameter to downsample anatomical volumes to dxyz mm\
            voxel resolution before registration.
        out_dxyz: Output the final aligned volume at a cubic voxelsize of\
            DXYZmm.
        wd: Use 3dWarpDrive's general affine transform (12 param) instead of\
            3dvolreg's 6 parameters.
        al: Use 3dAllineate to do the 12 parameter alignment. Cost function is\
            'lpa'.
        al_opt: Specify set of options to pass to 3dAllineate.
        ok_change_view: Be quiet when view of registered volume is changed to\
            match that of the Experiment_Anatomy.
        strip_skull: Use 3dSkullStrip to remove non-brain tissue.
        skull_strip_opt: Pass the options to 3dSkullStrip.
        align_centers: Add an additional transformation to align the volume\
            centers.
        init_xform: Apply affine transform file to Surface_Anatomy before\
            beginning registration.
        ea_clip_below: Set slices below CLPmm in 'Experiment Anatomy' to zero.
        prefix: Prefix for the output volume.
        surf_anat_followers: Apply the same alignment transform to additional\
            datasets.
        followers_interp: Set the interpolation mode for the follower datasets.
        atlas_followers: Automatically set the followers to be atlases in the\
            directory of -surf_anat.
        echo: Echo all commands to terminal for debugging.
        keep_tmp: Keep temporary files for debugging.
        overwrite_resp: Answer 'overwrite' questions automatically.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VSumaAlignToExperimentOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__SUMA_ALIGN_TO_EXPERIMENT_METADATA)
    cargs = []
    cargs.append("@SUMA_AlignToExperiment")
    cargs.extend([
        "-exp_anat",
        execution.input_file(exp_anat)
    ])
    cargs.extend([
        "-surf_anat",
        execution.input_file(surf_anat)
    ])
    if dxyz is not None:
        cargs.extend([
            "-dxyz",
            str(dxyz)
        ])
    if out_dxyz is not None:
        cargs.extend([
            "-out_dxyz",
            str(out_dxyz)
        ])
    if wd:
        cargs.append("-wd")
    if al:
        cargs.append("-al")
    if al_opt is not None:
        cargs.extend([
            "-al_opt",
            al_opt
        ])
    if ok_change_view:
        cargs.append("-ok_change_view")
    if strip_skull is not None:
        cargs.extend([
            "-strip_skull",
            strip_skull
        ])
    if skull_strip_opt is not None:
        cargs.extend([
            "-skull_strip_opt",
            skull_strip_opt
        ])
    if align_centers:
        cargs.append("-align_centers")
    if init_xform is not None:
        cargs.extend([
            "-init_xform",
            execution.input_file(init_xform)
        ])
    if ea_clip_below is not None:
        cargs.extend([
            "-EA_clip_below",
            str(ea_clip_below)
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if surf_anat_followers is not None:
        cargs.extend([
            "-surf_anat_followers",
            surf_anat_followers
        ])
    if followers_interp is not None:
        cargs.extend([
            "-followers_interp",
            followers_interp
        ])
    if atlas_followers:
        cargs.append("-atlas_followers")
    if echo:
        cargs.append("-echo")
    if keep_tmp:
        cargs.append("-keep_tmp")
    if overwrite_resp is not None:
        cargs.extend([
            "-overwrite_resp",
            overwrite_resp
        ])
    ret = VSumaAlignToExperimentOutputs(
        root=execution.output_file("."),
        aligned_volume=execution.output_file(prefix + "_Alnd_Exp.nii.gz") if (prefix is not None) else None,
        additional_followers=execution.output_file(prefix + "_Alnd_Exp_Fdset.nii.gz") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VSumaAlignToExperimentOutputs",
    "V__SUMA_ALIGN_TO_EXPERIMENT_METADATA",
    "v__suma_align_to_experiment",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

RUN_MESH_UTILS_METADATA = Metadata(
    id="f37cf2d8f5013ba6fbfc7ef807691e24ce397261.boutiques",
    name="run_mesh_utils",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class RunMeshUtilsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `run_mesh_utils(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image_file: OutputPathType
    """Output image file"""


def run_mesh_utils(
    base_mesh: InputPathType,
    output_image: str,
    input_image: InputPathType | None = None,
    second_input_image: InputPathType | None = None,
    weighting_image_force: InputPathType | None = None,
    runner: Runner | None = None,
) -> RunMeshUtilsOutputs:
    """
    A tool for various mesh operations as part of FSL.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        base_mesh: Filename of base mesh.
        output_image: Filename of output image.
        input_image: Filename of input image.
        second_input_image: Filename of second input image.
        weighting_image_force: Weighting image force.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RunMeshUtilsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(RUN_MESH_UTILS_METADATA)
    cargs = []
    cargs.append("run_mesh_utils")
    cargs.append(execution.input_file(base_mesh))
    cargs.extend([
        "-o",
        output_image
    ])
    if input_image is not None:
        cargs.extend([
            "-i",
            execution.input_file(input_image)
        ])
    if second_input_image is not None:
        cargs.extend([
            "-j",
            execution.input_file(second_input_image)
        ])
    if weighting_image_force is not None:
        cargs.extend([
            "-p",
            execution.input_file(weighting_image_force)
        ])
    cargs.append("[OPTIONAL_PARAMS...]")
    ret = RunMeshUtilsOutputs(
        root=execution.output_file("."),
        output_image_file=execution.output_file(output_image),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "RUN_MESH_UTILS_METADATA",
    "RunMeshUtilsOutputs",
    "run_mesh_utils",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LIST_OTL_LABELS_METADATA = Metadata(
    id="2093ee83fcca985e5be56e6cc6e4676af4aa43df.boutiques",
    name="list_otl_labels",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class ListOtlLabelsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `list_otl_labels(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def list_otl_labels(
    input_file: InputPathType,
    runner: Runner | None = None,
) -> ListOtlLabelsOutputs:
    """
    Tool for listing labels in an imaging file.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input volume filename.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ListOtlLabelsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LIST_OTL_LABELS_METADATA)
    cargs = []
    cargs.append("list_otl_labels")
    cargs.extend([
        "-i",
        execution.input_file(input_file)
    ])
    ret = ListOtlLabelsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LIST_OTL_LABELS_METADATA",
    "ListOtlLabelsOutputs",
    "list_otl_labels",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_AVERAGE_METADATA = Metadata(
    id="9f634edc8e7e1a23500b288fecc20c4dd605a410.boutiques",
    name="mri_average",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriAverageOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_average(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """The averaged output volume."""


def mri_average(
    input_volumes: list[InputPathType],
    output_volume: str,
    rigid_alignment: bool = False,
    read_from_file: bool = False,
    dt: float | None = None,
    tol: float | None = None,
    conform: bool = False,
    noconform: bool = False,
    reduce: float | None = None,
    sinc_interpolation: float | None = None,
    trilinear: bool = False,
    window: bool = False,
    snapshots: float | None = None,
    translation: list[float] | None = None,
    rotation: list[float] | None = None,
    momentum: float | None = None,
    rms_alt: bool = False,
    percent: bool = False,
    binarize: float | None = None,
    absolute: bool = False,
    runner: Runner | None = None,
) -> MriAverageOutputs:
    """
    Averages multiple volumes with various options for alignment, interpolation, and
    transformations.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volumes: Input volumes to average.
        output_volume: Output volume file.
        rigid_alignment: Rigid alignment of input volumes before averaging.
        read_from_file: Read volumes from an input file (first argument is the\
            input filename).
        dt: Set dt to n (default=1e-6).
        tol: Set tolerance to n (default=1e-5).
        conform: Interpolate volume to be isotropic 1mm^3 (on by default).
        noconform: Inhibit isotropic volume interpolation.
        reduce: Reduce input images n (default=2) times.
        sinc_interpolation: Using sinc interpolation with window width of 2*n\
            (default=3).
        trilinear: Use trilinear interpolation.
        window: Apply hanning window to volumes.
        snapshots: Write snapshots every n iterations.
        translation: Translation of second volume.
        rotation: Rotation of second volume around each axis in degrees.
        momentum: Use momentum n (default=0).
        rms_alt: Compute sqrt of average of sum of squares (RMS, same as -sqr).
        percent: Compute percentage.
        binarize: Binarize the input volumes using threshold th.
        absolute: Take absolute value of volume.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriAverageOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_AVERAGE_METADATA)
    cargs = []
    cargs.append("mri_average")
    cargs.extend([execution.input_file(f) for f in input_volumes])
    cargs.append(output_volume)
    if rigid_alignment:
        cargs.append("-a")
    if read_from_file:
        cargs.append("-F")
    if dt is not None:
        cargs.extend([
            "-dt",
            str(dt)
        ])
    if tol is not None:
        cargs.extend([
            "-tol",
            str(tol)
        ])
    if conform:
        cargs.append("-conform")
    if noconform:
        cargs.append("-noconform")
    if reduce is not None:
        cargs.extend([
            "-reduce",
            str(reduce)
        ])
    if sinc_interpolation is not None:
        cargs.extend([
            "-sinc",
            str(sinc_interpolation)
        ])
    if trilinear:
        cargs.append("-trilinear")
    if window:
        cargs.append("-window")
    if snapshots is not None:
        cargs.extend([
            "-w",
            str(snapshots)
        ])
    if translation is not None:
        cargs.extend([
            "-t",
            *map(str, translation)
        ])
    if rotation is not None:
        cargs.extend([
            "-r",
            *map(str, rotation)
        ])
    if momentum is not None:
        cargs.extend([
            "-m",
            str(momentum)
        ])
    if rms_alt:
        cargs.append("-rms")
    if percent:
        cargs.append("-p")
    if binarize is not None:
        cargs.extend([
            "-b",
            str(binarize)
        ])
    if absolute:
        cargs.append("-abs")
    ret = MriAverageOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_volume),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_AVERAGE_METADATA",
    "MriAverageOutputs",
    "mri_average",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_ZCUTUP_METADATA = Metadata(
    id="9f4c5ae0e2d25b35b3ce4085901c813b8cd03916.boutiques",
    name="3dZcutup",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dZcutupOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_zcutup(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_head: OutputPathType | None
    """The output dataset HEAD file"""
    output_brik: OutputPathType | None
    """The output dataset BRIK file"""


def v_3d_zcutup(
    keep_slices: str,
    dataset: InputPathType,
    prefix: str | None = None,
    runner: Runner | None = None,
) -> V3dZcutupOutputs:
    """
    Cut slices off a dataset in its z-direction and write a new dataset.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        keep_slices: Keep slices numbered 'b' through 't', inclusive. This is a\
            mandatory option. Slice numbers start at 0.
        dataset: The input dataset (e.g., epi07+orig). You can use a sub-brick\
            selector on the input dataset.
        prefix: Write result into dataset with the given prefix [default =\
            'zcutup'].
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dZcutupOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_ZCUTUP_METADATA)
    cargs = []
    cargs.append("3dZcutup")
    cargs.extend([
        "-keep",
        keep_slices
    ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    cargs.append(execution.input_file(dataset))
    ret = V3dZcutupOutputs(
        root=execution.output_file("."),
        output_head=execution.output_file(prefix + "+orig.HEAD") if (prefix is not None) else None,
        output_brik=execution.output_file(prefix + "+orig.BRIK") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dZcutupOutputs",
    "V_3D_ZCUTUP_METADATA",
    "v_3d_zcutup",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

QHULL_METADATA = Metadata(
    id="c66bd98623328e49e50c28ca6d4ac9a47c26c314.boutiques",
    name="qhull",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class QhullOutputs(typing.NamedTuple):
    """
    Output object returned when calling `qhull(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_results: OutputPathType | None
    """Output file with the specified results."""


def qhull(
    input_coords: str,
    delaunay: bool = False,
    furthest_delaunay: bool = False,
    voronoi: bool = False,
    furthest_voronoi: bool = False,
    halfspace_intersection: bool = False,
    triangulated_output: bool = False,
    joggled_input: bool = False,
    verify: bool = False,
    summary: bool = False,
    vertices_incident: bool = False,
    normals: bool = False,
    vertex_coordinates: bool = False,
    halfspace_intersections: bool = False,
    extreme_points: bool = False,
    total_area_volume: bool = False,
    off_format: bool = False,
    geomview_output: bool = False,
    mathematica_output: bool = False,
    print_facets: str | None = None,
    output_file: InputPathType | None = None,
    runner: Runner | None = None,
) -> QhullOutputs:
    """
    Tool to compute convex hulls and related structures.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_coords: Dimension, number of points, and point coordinates\
            provided via stdin.
        delaunay: Compute Delaunay triangulation by lifting points to a\
            paraboloid.
        furthest_delaunay: Compute furthest-site Delaunay triangulation (upper\
            convex hull).
        voronoi: Compute Voronoi diagram as the dual of the Delaunay\
            triangulation.
        furthest_voronoi: Compute furthest-site Voronoi diagram.
        halfspace_intersection: Compute halfspace intersection about\
            [1,1,0,...] via polar duality.
        triangulated_output: Triangulated output.
        joggled_input: Joggled input instead of merged facets.
        verify: Verify result: structure, convexity, and point inclusion.
        summary: Summary of results.
        vertices_incident: Vertices incident to each facet.
        normals: Normals with offsets.
        vertex_coordinates: Vertex coordinates (if 'Qc', includes coplanar\
            points). If 'v', Voronoi vertices.
        halfspace_intersections: Halfspace intersections.
        extreme_points: Extreme points (convex hull vertices).
        total_area_volume: Compute total area and volume.
        off_format: OFF format (if 'v', outputs Voronoi regions).
        geomview_output: Geomview output (2-d, 3-d and 4-d).
        mathematica_output: Mathematica output (2-d and 3-d).
        print_facets: Print facets that include point n, -n if not.
        output_file: Output results to file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `QhullOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(QHULL_METADATA)
    cargs = []
    cargs.append("qhull")
    cargs.append(input_coords)
    if delaunay:
        cargs.append("d")
    if furthest_delaunay:
        cargs.append("d Qu")
    if voronoi:
        cargs.append("v")
    if furthest_voronoi:
        cargs.append("v Qu")
    if halfspace_intersection:
        cargs.append("H1,1")
    if triangulated_output:
        cargs.append("Qt")
    if joggled_input:
        cargs.append("QJ")
    if verify:
        cargs.append("Tv")
    if summary:
        cargs.append("s")
    if vertices_incident:
        cargs.append("i")
    if normals:
        cargs.append("n")
    if vertex_coordinates:
        cargs.append("p")
    if halfspace_intersections:
        cargs.append("Fp")
    if extreme_points:
        cargs.append("Fx")
    if total_area_volume:
        cargs.append("FA")
    if off_format:
        cargs.append("o")
    if geomview_output:
        cargs.append("G")
    if mathematica_output:
        cargs.append("m")
    if print_facets is not None:
        cargs.extend([
            "QVn",
            print_facets
        ])
    if output_file is not None:
        cargs.extend([
            "TO",
            execution.input_file(output_file)
        ])
    ret = QhullOutputs(
        root=execution.output_file("."),
        output_results=execution.output_file(pathlib.Path(output_file).name + ".txt") if (output_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "QHULL_METADATA",
    "QhullOutputs",
    "qhull",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_REGISTER_TO_LABEL_METADATA = Metadata(
    id="36d8ca89ec62d6d129c91373f3bc303868500379.boutiques",
    name="mris_register_to_label",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisRegisterToLabelOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_register_to_label(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_register_to_label(
    surface: InputPathType,
    regfile: InputPathType,
    mri_reg: InputPathType,
    mov_volume: InputPathType,
    resolution: float,
    max_rot: float | None = None,
    max_trans: float | None = None,
    subject: str | None = None,
    label: str | None = None,
    out_reg: str | None = None,
    downsample: float | None = None,
    cost_file: InputPathType | None = None,
    runner: Runner | None = None,
) -> MrisRegisterToLabelOutputs:
    """
    Register a surface to a volume using a label.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        surface: Surface file for registration.
        regfile: Registration file.
        mri_reg: Volume for MRI registration.
        mov_volume: Volume on which label points are specified.
        resolution: Resolution for calculations.
        max_rot: Maximum angle (degrees) to search over for rotation.
        max_trans: Maximum translation (mm) to search over.
        subject: Specify name of subject for register.dat file.
        label: Load label and limit calculations to it.
        out_reg: Output registration at lowest cost.
        downsample: Downsample input volume by a factor.
        cost_file: Cost file for registration.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisRegisterToLabelOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_REGISTER_TO_LABEL_METADATA)
    cargs = []
    cargs.append("mris_register_to_label")
    cargs.extend([
        "--surf",
        execution.input_file(surface)
    ])
    cargs.extend([
        "--reg",
        execution.input_file(regfile)
    ])
    cargs.extend([
        "--mri_reg",
        execution.input_file(mri_reg)
    ])
    cargs.extend([
        "--mov",
        execution.input_file(mov_volume)
    ])
    cargs.extend([
        "--res",
        str(resolution)
    ])
    if max_rot is not None:
        cargs.extend([
            "--max_rot",
            str(max_rot)
        ])
    if max_trans is not None:
        cargs.extend([
            "--max_trans",
            str(max_trans)
        ])
    if subject is not None:
        cargs.extend([
            "--s",
            subject
        ])
    if label is not None:
        cargs.extend([
            "--label",
            label
        ])
    if out_reg is not None:
        cargs.extend([
            "--out-reg",
            out_reg
        ])
    if downsample is not None:
        cargs.extend([
            "--downsample",
            str(downsample)
        ])
    if cost_file is not None:
        cargs.extend([
            "--cost",
            execution.input_file(cost_file)
        ])
    ret = MrisRegisterToLabelOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_REGISTER_TO_LABEL_METADATA",
    "MrisRegisterToLabelOutputs",
    "mris_register_to_label",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

RUN_SAMSEG_METADATA = Metadata(
    id="44643a5ac5bf2fd988d84ca267e8388b307ea24d.boutiques",
    name="run_samseg",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class RunSamsegOutputs(typing.NamedTuple):
    """
    Output object returned when calling `run_samseg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def run_samseg(
    output_dir: str,
    input_files: list[InputPathType],
    input_mode: list[str] | None = None,
    threads: float | None = None,
    reg_only: bool = False,
    reg_file: InputPathType | None = None,
    init_reg_file: InputPathType | None = None,
    atlas_dir: str | None = None,
    gmm_file: InputPathType | None = None,
    ignore_unknown: bool = False,
    options_file: InputPathType | None = None,
    pallidum_separate: bool = False,
    mesh_stiffness: float | None = None,
    smooth_wm_cortex_priors: float | None = None,
    bias_field_smoothing_kernel: float | None = None,
    lesion: bool = False,
    threshold: float | None = None,
    samples: float | None = None,
    burnin: float | None = None,
    lesion_pseudo_samples: list[float] | None = None,
    lesion_rho: float | None = None,
    lesion_mask_structure: str | None = None,
    lesion_mask_pattern: list[float] | None = None,
    random_seed: float | None = None,
    dissection_photo: str | None = None,
    history: bool = False,
    save_posteriors: list[str] | None = None,
    save_probabilities: bool = False,
    showfigs: bool = False,
    save_mesh: bool = False,
    save_warp: bool = False,
    movie: bool = False,
    runner: Runner | None = None,
) -> RunSamsegOutputs:
    """
    SAMSEG (Sequence Adaptive Multimodal SEGmentation) is a tool for automated
    segmentation of brain MRI data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        output_dir: Target directory for output.
        input_files: Input image(s) for segmentation.
        input_mode: Output basenames for the input image mode.
        threads: Number of threads to use.
        reg_only: Only perform initial affine registration.
        reg_file: Skip initial affine registration and read transform from\
            file.
        init_reg_file: Initial affine registration.
        atlas_dir: Point to an alternative atlas directory.
        gmm_file: Point to an alternative GMM file.
        ignore_unknown: Ignore final priors corresponding to unknown class.
        options_file: Override advanced options via a JSON file.
        pallidum_separate: Move pallidum outside of global white matter class.
        mesh_stiffness: Override mesh stiffness.
        smooth_wm_cortex_priors: Sigma value to smooth the WM and cortex atlas\
            priors.
        bias_field_smoothing_kernel: Distance in mm of sinc function center to\
            first zero crossing.
        lesion: Enable lesion segmentation (requires tensorflow).
        threshold: Lesion threshold for final segmentation.
        samples: Number of samples for lesion segmentation.
        burnin: Number of burn-in samples for lesion segmentation.
        lesion_pseudo_samples: Lesion pseudo samples mean and variance.
        lesion_rho: Lesion ratio.
        lesion_mask_structure: Intensity mask brain structure.
        lesion_mask_pattern: Lesion mask pattern for each input volume.
        random_seed: Random seed.
        dissection_photo: Specify hemispheres: left, right, or both.
        history: Save history of segmentation.
        save_posteriors: Save posterior volumes.
        save_probabilities: Save modal class probabilities.
        showfigs: Show figures during run.
        save_mesh: Save final mesh in template space.
        save_warp: Save image->template warp field.
        movie: Show history as controlled time sequence.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RunSamsegOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(RUN_SAMSEG_METADATA)
    cargs = []
    cargs.append("run_samseg")
    cargs.extend([
        "-o",
        output_dir
    ])
    cargs.extend([
        "-i",
        *[execution.input_file(f) for f in input_files]
    ])
    if input_mode is not None:
        cargs.extend([
            "-m",
            *input_mode
        ])
    if threads is not None:
        cargs.extend([
            "--threads",
            str(threads)
        ])
    if reg_only:
        cargs.append("--reg-only")
    if reg_file is not None:
        cargs.extend([
            "-r",
            execution.input_file(reg_file)
        ])
    if init_reg_file is not None:
        cargs.extend([
            "--init-reg",
            execution.input_file(init_reg_file)
        ])
    if atlas_dir is not None:
        cargs.extend([
            "-a",
            atlas_dir
        ])
    if gmm_file is not None:
        cargs.extend([
            "--gmm",
            execution.input_file(gmm_file)
        ])
    if ignore_unknown:
        cargs.append("--ignore-unknown")
    if options_file is not None:
        cargs.extend([
            "--options",
            execution.input_file(options_file)
        ])
    if pallidum_separate:
        cargs.append("--pallidum-separate")
    if mesh_stiffness is not None:
        cargs.extend([
            "--mesh-stiffness",
            str(mesh_stiffness)
        ])
    if smooth_wm_cortex_priors is not None:
        cargs.extend([
            "--smooth-wm-cortex-priors",
            str(smooth_wm_cortex_priors)
        ])
    if bias_field_smoothing_kernel is not None:
        cargs.extend([
            "--bias-field-smoothing-kernel",
            str(bias_field_smoothing_kernel)
        ])
    if lesion:
        cargs.append("--lesion")
    if threshold is not None:
        cargs.extend([
            "--threshold",
            str(threshold)
        ])
    if samples is not None:
        cargs.extend([
            "--samples",
            str(samples)
        ])
    if burnin is not None:
        cargs.extend([
            "--burnin",
            str(burnin)
        ])
    if lesion_pseudo_samples is not None:
        cargs.extend([
            "--lesion-pseudo-samples",
            *map(str, lesion_pseudo_samples)
        ])
    if lesion_rho is not None:
        cargs.extend([
            "--lesion-rho",
            str(lesion_rho)
        ])
    if lesion_mask_structure is not None:
        cargs.extend([
            "--lesion-mask-structure",
            lesion_mask_structure
        ])
    if lesion_mask_pattern is not None:
        cargs.extend([
            "--lesion-mask-pattern",
            *map(str, lesion_mask_pattern)
        ])
    if random_seed is not None:
        cargs.extend([
            "--random-seed",
            str(random_seed)
        ])
    if dissection_photo is not None:
        cargs.extend([
            "--dissection-photo",
            dissection_photo
        ])
    if history:
        cargs.append("--history")
    if save_posteriors is not None:
        cargs.extend([
            "--save-posteriors",
            *save_posteriors
        ])
    if save_probabilities:
        cargs.append("--save-probabilities")
    if showfigs:
        cargs.append("--showfigs")
    if save_mesh:
        cargs.append("--save-mesh")
    if save_warp:
        cargs.append("--save-warp")
    if movie:
        cargs.append("--movie")
    ret = RunSamsegOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "RUN_SAMSEG_METADATA",
    "RunSamsegOutputs",
    "run_samseg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

THICKDIFFMAP_METADATA = Metadata(
    id="386d35dd120f181e0cd722b783b2ab7dab134ec4.boutiques",
    name="thickdiffmap",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class ThickdiffmapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `thickdiffmap(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def thickdiffmap(
    subjscan1: InputPathType,
    subjscan2: InputPathType,
    commonsubj: str,
    hemi: str,
    steps: list[str] | None = None,
    runner: Runner | None = None,
) -> ThickdiffmapOutputs:
    """
    Compute and analyze cortical thickness difference maps.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subjscan1: First scan of a subject.
        subjscan2: Second (later) scan of the same subject.
        commonsubj: Subject to use as the common template.
        hemi: Hemisphere to process.
        steps: Stages of processing.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ThickdiffmapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(THICKDIFFMAP_METADATA)
    cargs = []
    cargs.append("thickdiffmap")
    cargs.append(execution.input_file(subjscan1))
    cargs.append(execution.input_file(subjscan2))
    cargs.append(commonsubj)
    cargs.append(hemi)
    if steps is not None:
        cargs.extend(steps)
    ret = ThickdiffmapOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "THICKDIFFMAP_METADATA",
    "ThickdiffmapOutputs",
    "thickdiffmap",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FS_PRINT_HELP_METADATA = Metadata(
    id="a91a6c5c64fb27bc188a085d7211176975d7d7d4.boutiques",
    name="fsPrintHelp",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FsPrintHelpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fs_print_help(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fs_print_help(
    arguments: str | None = None,
    runner: Runner | None = None,
) -> FsPrintHelpOutputs:
    """
    fsPrintHelp - A tool that attempts to provide help documentation for FreeSurfer
    commands.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        arguments: Any arguments that fsPrintHelp accepts.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FsPrintHelpOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FS_PRINT_HELP_METADATA)
    cargs = []
    cargs.append("fsPrintHelp")
    if arguments is not None:
        cargs.append(arguments)
    ret = FsPrintHelpOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FS_PRINT_HELP_METADATA",
    "FsPrintHelpOutputs",
    "fs_print_help",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_REG_ANA_METADATA = Metadata(
    id="1631118904756d1061212c150565890bf979dbc0.boutiques",
    name="3dRegAna",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dRegAnaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_reg_ana(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_fift: OutputPathType
    """Output fift dataset"""
    output_fith: OutputPathType
    """Output fith dataset"""
    output_fitt: OutputPathType
    """Output fitt dataset"""
    output_bucket: OutputPathType
    """Output bucket dataset"""
    output_bucket_brik: OutputPathType
    """Output bucket BRIK file"""


def v_3d_reg_ana(
    rows: float,
    cols: float,
    xydata: list[str],
    model: str,
    diskspace: bool = False,
    workmem: float | None = None,
    rmsmin: float | None = None,
    fdisp: float | None = None,
    flof: float | None = None,
    fcoef: list[str] | None = None,
    rcoef: list[str] | None = None,
    tcoef: list[str] | None = None,
    bucket: str | None = None,
    brick: list[str] | None = None,
    datum: str | None = None,
    runner: Runner | None = None,
) -> V3dRegAnaOutputs:
    """
    Multiple linear regression analysis for AFNI datasets.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        rows: Number of input datasets.
        cols: Number of X variables.
        xydata: X variables and Y observations.
        model: Definition of linear regression model: reduced model (Y =\
            f(Xj1,...,Xjr)) and full model (Y = f(Xj1,...,Xjr,Xi1,...,Xiq)).
        diskspace: Print out disk space required for program execution.
        workmem: Number of megabytes of RAM to use for statistical workspace\
            (default = 750).
        rmsmin: Minimum rms error to reject constant model.
        fdisp: Display results for voxels whose F-statistic is > fval.
        flof: Minimum p value for F due to lack of fit.
        fcoef: Estimate of kth regression coefficient along with F-test for the\
            regression is written to AFNI `fift` dataset.
        rcoef: Estimate of kth regression coefficient along with coef. of mult.\
            deter. R^2 is written to AFNI `fith` dataset.
        tcoef: Estimate of kth regression coefficient along with t-test for the\
            coefficient is written to AFNI `fitt` dataset.
        bucket: Create one AFNI 'bucket' dataset having n sub-bricks; n=0\
            creates default output.
        brick: Specify the contents of the mth sub-brick in the bucket dataset.
        datum: Write the output in DATUM format. Choose from short (default) or\
            float.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dRegAnaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_REG_ANA_METADATA)
    cargs = []
    cargs.append("3dRegAna")
    cargs.extend([
        "-rows",
        str(rows)
    ])
    cargs.extend([
        "-cols",
        str(cols)
    ])
    cargs.extend([
        "-xydata",
        *xydata
    ])
    cargs.extend([
        "-model",
        model
    ])
    if diskspace:
        cargs.append("-diskspace")
    if workmem is not None:
        cargs.extend([
            "-workmem",
            str(workmem)
        ])
    if rmsmin is not None:
        cargs.extend([
            "-rmsmin",
            str(rmsmin)
        ])
    if fdisp is not None:
        cargs.extend([
            "-fdisp",
            str(fdisp)
        ])
    if flof is not None:
        cargs.extend([
            "-flof",
            str(flof)
        ])
    if fcoef is not None:
        cargs.extend([
            "-fcoef",
            *fcoef
        ])
    if rcoef is not None:
        cargs.extend([
            "-rcoef",
            *rcoef
        ])
    if tcoef is not None:
        cargs.extend([
            "-tcoef",
            *tcoef
        ])
    if bucket is not None:
        cargs.extend([
            "-bucket",
            bucket
        ])
    if brick is not None:
        cargs.extend([
            "-brick",
            *brick
        ])
    if datum is not None:
        cargs.extend([
            "-datum",
            datum
        ])
    ret = V3dRegAnaOutputs(
        root=execution.output_file("."),
        output_fift=execution.output_file("[PREFIX].fift+orig.HEAD"),
        output_fith=execution.output_file("[PREFIX].fith+orig.HEAD"),
        output_fitt=execution.output_file("[PREFIX].fitt+orig.HEAD"),
        output_bucket=execution.output_file("[PREFIX].bucket+orig.HEAD"),
        output_bucket_brik=execution.output_file("[PREFIX].bucket+orig.BRIK"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dRegAnaOutputs",
    "V_3D_REG_ANA_METADATA",
    "v_3d_reg_ana",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSVGLRUN_METADATA = Metadata(
    id="5ac643a495dfd3b7b90655e3aff808accc7f76dd.boutiques",
    name="fsvglrun",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FsvglrunOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsvglrun(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fsvglrun(
    command: str,
    zeroth_arg_name: str | None = None,
    empty_env: bool = False,
    dashed_arg: bool = False,
    command_args: list[str] | None = None,
    runner: Runner | None = None,
) -> FsvglrunOutputs:
    """
    A tool to execute a command, replacing the shell with the specified program,
    typically used within FreeSurfer environment.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        command: The command to be executed, replacing the shell with the\
            specified program.
        zeroth_arg_name: Pass NAME as the zeroth argument to COMMAND.
        empty_env: Execute COMMAND with an empty environment.
        dashed_arg: Place a dash in the zeroth argument to COMMAND.
        command_args: Arguments for the command executed by fsvglrun.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FsvglrunOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSVGLRUN_METADATA)
    cargs = []
    cargs.append("fsvglrun")
    if zeroth_arg_name is not None:
        cargs.extend([
            "-a",
            zeroth_arg_name
        ])
    if empty_env:
        cargs.append("-c")
    if dashed_arg:
        cargs.append("-l")
    cargs.append(command)
    if command_args is not None:
        cargs.extend(command_args)
    ret = FsvglrunOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSVGLRUN_METADATA",
    "FsvglrunOutputs",
    "fsvglrun",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

COR_TO_MINC_METADATA = Metadata(
    id="40b8ba63752dc024cdd4c61323a6a2c0ec2b41fb.boutiques",
    name="cor_to_minc",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class CorToMincOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cor_to_minc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_minc: OutputPathType
    """Converted MINC file"""


def cor_to_minc(
    cor_directory: str,
    minc_file: str,
    runner: Runner | None = None,
) -> CorToMincOutputs:
    """
    Converts a directory of COR files to a MINC file.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        cor_directory: Directory containing COR files.
        minc_file: Output MINC file name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CorToMincOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(COR_TO_MINC_METADATA)
    cargs = []
    cargs.append("cor_to_minc")
    cargs.append(cor_directory)
    cargs.append(minc_file)
    ret = CorToMincOutputs(
        root=execution.output_file("."),
        output_minc=execution.output_file(minc_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "COR_TO_MINC_METADATA",
    "CorToMincOutputs",
    "cor_to_minc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

PCTSURFCON_METADATA = Metadata(
    id="0e082a082c6b181a71427db52d685c35d4270743.boutiques",
    name="pctsurfcon",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class PctsurfconOutputs(typing.NamedTuple):
    """
    Output object returned when calling `pctsurfcon(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def pctsurfcon(
    subject: str,
    fsvol: str | None = None,
    outbase: str | None = None,
    lh_only: bool = False,
    rh_only: bool = False,
    gm_proj_frac: float | None = None,
    gm_proj_abs: float | None = None,
    wm_proj_abs: float | None = None,
    neg: bool = False,
    no_mask: bool = False,
    pial: bool = False,
    tmp: str | None = None,
    nocleanup: bool = False,
    runner: Runner | None = None,
) -> PctsurfconOutputs:
    """
    Compute surface-wise gray/white matter contrast.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: FreeSurfer subject name.
        fsvol: Use fsvol instead of rawavg.
        outbase: Use outbase instead of w-g.pct (?h.w-g.pct.mgh).
        lh_only: Compute left hemisphere only.
        rh_only: Compute right hemisphere only.
        gm_proj_frac: GM projection fraction (default 0.3).
        gm_proj_abs: GM projection distance (default is to use frac).
        wm_proj_abs: WM projection distance (default is 1 mm).
        neg: Compute G-W instead of W-G.
        no_mask: Do not mask out non-cortical regions.
        pial: Use pial surface as base to compute gray/CSF contrast.
        tmp: Temporary directory (implies --nocleanup).
        nocleanup: Do not delete temporary files.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PctsurfconOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(PCTSURFCON_METADATA)
    cargs = []
    cargs.append("pctsurfcon")
    cargs.extend([
        "-s",
        "-" + subject
    ])
    if fsvol is not None:
        cargs.extend([
            "--fsvol",
            fsvol
        ])
    if outbase is not None:
        cargs.extend([
            "--b",
            outbase
        ])
    if lh_only:
        cargs.append("--lh-only")
    if rh_only:
        cargs.append("--rh-only")
    if gm_proj_frac is not None:
        cargs.extend([
            "--gm-proj-frac",
            str(gm_proj_frac)
        ])
    if gm_proj_abs is not None:
        cargs.extend([
            "--gm-proj-abs",
            str(gm_proj_abs)
        ])
    if wm_proj_abs is not None:
        cargs.extend([
            "--wm-proj-abs",
            str(wm_proj_abs)
        ])
    if neg:
        cargs.append("--neg")
    if no_mask:
        cargs.append("--no-mask")
    if pial:
        cargs.append("--pial")
    if tmp is not None:
        cargs.extend([
            "--tmp",
            tmp
        ])
    if nocleanup:
        cargs.append("--nocleanup")
    ret = PctsurfconOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "PCTSURFCON_METADATA",
    "PctsurfconOutputs",
    "pctsurfcon",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_TRACK_ID_METADATA = Metadata(
    id="8ab0520e610553f06eae7348796632b2a5eda40e.boutiques",
    name="3dTrackID",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dTrackIdOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_track_id(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    indimap: OutputPathType
    """Output of INDIMAP"""
    pairmap: OutputPathType
    """Output of PAIRMAP"""
    grid: OutputPathType
    """Text file output of statistics of WM-ROIs"""
    niml_tract: OutputPathType
    """Track-like output for viewing in SUMA"""
    niml_dset: OutputPathType
    """Dataset output for use with *.niml.tract"""
    trk: OutputPathType
    """TrackVis-like output for viewing in TrackVis"""
    pairmap_labeltable: OutputPathType
    """Output of PAIRMAP labeltable"""
    roi_labels: OutputPathType
    """Output file of all ROI labels"""
    option_values: OutputPathType
    """Output of all option values"""


def v_3d_track_id(
    mode: typing.Literal["DET", "MINIP", "PROB"],
    netrois: InputPathType,
    prefix: str,
    logic: typing.Literal["OR", "AND"],
    dti_in: str | None = None,
    dti_list: InputPathType | None = None,
    dti_extra: str | None = None,
    dti_search_no: bool = False,
    hardi_gfa: InputPathType | None = None,
    hardi_dirs: InputPathType | None = None,
    hardi_pars: str | None = None,
    mask: InputPathType | None = None,
    thru_mask: InputPathType | None = None,
    targ_surf_stop: bool = False,
    targ_surf_twixt: bool = False,
    mini_num: float | None = None,
    uncert: InputPathType | None = None,
    unc_min_fa: float | None = None,
    unc_min_v: float | None = None,
    algopt: InputPathType | None = None,
    alg_thresh_fa: float | None = None,
    alg_thresh_ang: float | None = None,
    alg_thresh_len: float | None = None,
    alg_nseed_x: float | None = None,
    alg_nseed_y: float | None = None,
    alg_nseed_z: float | None = None,
    alg_thresh_frac: float | None = None,
    alg_nseed_vox: float | None = None,
    alg_nmonte: float | None = None,
    extra_tr_par: bool = False,
    uncut_at_rois: bool = False,
    dump_rois: typing.Literal["DUMP", "AFNI", "BOTH", "AFNI_MAP"] | None = None,
    dump_no_labtab: bool = False,
    dump_lab_consec: bool = False,
    posteriori: bool = False,
    rec_orig: bool = False,
    do_trk_out: bool = False,
    trk_opp_orient: bool = False,
    nifti: bool = False,
    no_indipair_out: bool = False,
    write_rois: bool = False,
    write_opts: bool = False,
    pair_out_power: bool = False,
    verb: float | None = None,
    runner: Runner | None = None,
) -> V3dTrackIdOutputs:
    """
    FACTID-based tractography code for AFNI, part of FATCAT.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        mode: The mode of tracking: DET, MINIP, or PROB.
        netrois: Network ROI mask(s).
        prefix: Prefix for output files.
        logic: Control logic connections among target ROIs per network.
        dti_in: Input DTI volumes basename.
        dti_list: Alternative way to specify DTI input files, a NIML-formatted\
            text file.
        dti_extra: Option for extra scalar for WM skeleton thresholding.
        dti_search_no: Turn off automatic search for additional scalar files to\
            include in output.
        hardi_gfa: Single brik dataset with generalized FA (GFA) info.
        hardi_dirs: Directions file for HARDI data containing directions\
            components.
        hardi_pars: Prefix to search for scalar files naming format.
        mask: Mask within which tracking is done. Optional but highly\
            recommended.
        thru_mask: Extra restrictor mask through which paths are strictly\
            required to pass.
        targ_surf_stop: Make tracts stop at outer surfaces of the target ROIs.
        targ_surf_twixt: Make tracts stop just before entering target surfaces.
        mini_num: Number of whole brain Monte Carlo iterations for\
            mini-probabilistic tracking.
        uncert: Uncertainty values file.
        unc_min_fa: Minimum stdev for perturbing FA.
        unc_min_v: Minimum stdev for perturbing direction-vectors.
        algopt: Specify tracking parameter quantities file in ASCII.
        alg_thresh_fa: Set threshold for FA map or other WM proxy.
        alg_thresh_ang: Set maximum angle for turning during propagation.
        alg_thresh_len: Set minimum physical length of tracts to keep.
        alg_nseed_x: Number of seeds per voxel in x-direction.
        alg_nseed_y: Number of seeds per voxel in y-direction.
        alg_nseed_z: Number of seeds per voxel in z-direction.
        alg_thresh_frac: Value for thresholding the fraction of tracks through\
            a voxel for a given connection.
        alg_nseed_vox: Number of seeds per voxel per Monte Carlo iteration.
        alg_nmonte: Number of Monte Carlo iterations.
        extra_tr_par: Run three extra track parameter scalings for each\
            connection.
        uncut_at_rois: Keep entire track even if overshoots a target.
        dump_rois: Output individual masks of ROI connections.
        dump_no_labtab: Turn off label table use in ROI dump output.
        dump_lab_consec: DON'T apply numerical labels of original ROIs in dump\
            output.
        posteriori: Output individual files with number of tracks per voxel per\
            pair.
        rec_orig: Record dataset origin in header of *.trk file.
        do_trk_out: Output *.trk files for viewing in TrackVis.
        trk_opp_orient: Oppositize voxel_order for TRK files.
        nifti: Output files in *.nii.gz format.
        no_indipair_out: Do not output INDIMAP and PAIRMAP volumes.
        write_rois: Write out ROI labels.
        write_opts: Write out all option values.
        pair_out_power: Switch to use powers of two labelling for PAIRMAP.
        verb: Set verbosity level.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dTrackIdOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_TRACK_ID_METADATA)
    cargs = []
    cargs.append("3dTrackID")
    cargs.append(mode)
    cargs.append(execution.input_file(netrois))
    cargs.append(prefix)
    if dti_in is not None:
        cargs.append(dti_in)
    if dti_list is not None:
        cargs.append(execution.input_file(dti_list))
    if dti_extra is not None:
        cargs.append(dti_extra)
    if dti_search_no:
        cargs.append("-dti_search_NO")
    if hardi_gfa is not None:
        cargs.append(execution.input_file(hardi_gfa))
    if hardi_dirs is not None:
        cargs.append(execution.input_file(hardi_dirs))
    if hardi_pars is not None:
        cargs.append(hardi_pars)
    if mask is not None:
        cargs.append(execution.input_file(mask))
    if thru_mask is not None:
        cargs.append(execution.input_file(thru_mask))
    if targ_surf_stop:
        cargs.append("-targ_surf_stop")
    if targ_surf_twixt:
        cargs.append("-targ_surf_twixt")
    cargs.append(logic)
    if mini_num is not None:
        cargs.append(str(mini_num))
    if uncert is not None:
        cargs.append(execution.input_file(uncert))
    if unc_min_fa is not None:
        cargs.append(str(unc_min_fa))
    if unc_min_v is not None:
        cargs.append(str(unc_min_v))
    if algopt is not None:
        cargs.append(execution.input_file(algopt))
    if alg_thresh_fa is not None:
        cargs.append(str(alg_thresh_fa))
    if alg_thresh_ang is not None:
        cargs.append(str(alg_thresh_ang))
    if alg_thresh_len is not None:
        cargs.append(str(alg_thresh_len))
    if alg_nseed_x is not None:
        cargs.append(str(alg_nseed_x))
    if alg_nseed_y is not None:
        cargs.append(str(alg_nseed_y))
    if alg_nseed_z is not None:
        cargs.append(str(alg_nseed_z))
    if alg_thresh_frac is not None:
        cargs.append(str(alg_thresh_frac))
    if alg_nseed_vox is not None:
        cargs.append(str(alg_nseed_vox))
    if alg_nmonte is not None:
        cargs.append(str(alg_nmonte))
    if extra_tr_par:
        cargs.append("-extra_tr_par")
    if uncut_at_rois:
        cargs.append("-uncut_at_rois")
    if dump_rois is not None:
        cargs.append(dump_rois)
    if dump_no_labtab:
        cargs.append("-dump_no_labtab")
    if dump_lab_consec:
        cargs.append("-dump_lab_consec")
    if posteriori:
        cargs.append("-posteriori")
    if rec_orig:
        cargs.append("-rec_orig")
    if do_trk_out:
        cargs.append("-do_trk_out")
    if trk_opp_orient:
        cargs.append("-trk_opp_orient")
    if nifti:
        cargs.append("-nifti")
    if no_indipair_out:
        cargs.append("-no_indipair_out")
    if write_rois:
        cargs.append("-write_rois")
    if write_opts:
        cargs.append("-write_opts")
    if pair_out_power:
        cargs.append("-pair_out_power")
    if verb is not None:
        cargs.append(str(verb))
    ret = V3dTrackIdOutputs(
        root=execution.output_file("."),
        indimap=execution.output_file(prefix + "_INDIMAP.nii.gz"),
        pairmap=execution.output_file(prefix + "_PAIRMAP.nii.gz"),
        grid=execution.output_file(prefix + ".grid"),
        niml_tract=execution.output_file(prefix + ".niml.tract"),
        niml_dset=execution.output_file(prefix + ".niml.dset"),
        trk=execution.output_file(prefix + ".trk"),
        pairmap_labeltable=execution.output_file(prefix + "_PAIRS.niml.lt"),
        roi_labels=execution.output_file(prefix + "_roi.labs"),
        option_values=execution.output_file(prefix + ".niml.opts"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dTrackIdOutputs",
    "V_3D_TRACK_ID_METADATA",
    "v_3d_track_id",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DHISTOG_METADATA = Metadata(
    id="e7bd0d2e8a320bbb6bd63ecc03a72a5a7207b971.boutiques",
    name="3dhistog",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dhistogOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dhistog(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    histogram_output: OutputPathType
    """Histogram output when -prefix option is used"""


def v_3dhistog(
    dataset: InputPathType,
    nbin: float | None = None,
    dind: float | None = None,
    omit: list[float] | None = None,
    mask: InputPathType | None = None,
    roi_mask: InputPathType | None = None,
    doall: bool = False,
    noempty: bool = False,
    notitle: bool = False,
    log10: bool = False,
    pdf: bool = False,
    min_: float | None = None,
    max_: float | None = None,
    igfac: bool = False,
    int_: bool = False,
    float_: bool = False,
    unq: str | None = None,
    prefix: str | None = None,
    runner: Runner | None = None,
) -> V3dhistogOutputs:
    """
    Compute histogram of a 3D dataset.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        dataset: Input dataset.
        nbin: Use specified number of bins.
        dind: Use data from specified sub-brick index.
        omit: Omit specified value from the count.
        mask: Use mask dataset to determine which voxels to use.
        roi_mask: Create histogram for each non-zero value in 'r' dataset.
        doall: Include all sub-bricks in the calculation.
        noempty: Only output bins that are not empty.
        notitle: Leave the title line off the output.
        log10: Output log10() of the counts.
        pdf: Output the counts divided by the number of samples.
        min_: Specify minimum (inclusive) of histogram.
        max_: Specify maximum (inclusive) of histogram.
        igfac: Ignore sub-brick scale factors and histogram-ize the 'raw' data.
        int_: Treat data and output as integers.
        float_: Treat data and output as floats.
        unq: Writes out the sorted unique values to file.
        prefix: Write a copy of the histogram into specified file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dhistogOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DHISTOG_METADATA)
    cargs = []
    cargs.append("3dhistog")
    cargs.append(execution.input_file(dataset))
    if nbin is not None:
        cargs.extend([
            "-nbin",
            str(nbin)
        ])
    if dind is not None:
        cargs.extend([
            "-dind",
            str(dind)
        ])
    if omit is not None:
        cargs.extend([
            "-omit",
            *map(str, omit)
        ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if roi_mask is not None:
        cargs.extend([
            "-roi_mask",
            execution.input_file(roi_mask)
        ])
    if doall:
        cargs.append("-doall")
    if noempty:
        cargs.append("-noempty")
    if notitle:
        cargs.append("-notitle")
    if log10:
        cargs.append("-log10")
    if pdf:
        cargs.append("-pdf")
    if min_ is not None:
        cargs.extend([
            "-min",
            str(min_)
        ])
    if max_ is not None:
        cargs.extend([
            "-max",
            str(max_)
        ])
    if igfac:
        cargs.append("-igfac")
    if int_:
        cargs.append("-int")
    if float_:
        cargs.append("-float")
    if unq is not None:
        cargs.extend([
            "-unq",
            unq
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    ret = V3dhistogOutputs(
        root=execution.output_file("."),
        histogram_output=execution.output_file("HOUT.1D"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dhistogOutputs",
    "V_3DHISTOG_METADATA",
    "v_3dhistog",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SRATIO_METADATA = Metadata(
    id="b9e1c106ac7eb065c902d7e719b87ca6cd2c12c5.boutiques",
    name="sratio",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class SratioOutputs(typing.NamedTuple):
    """
    Output object returned when calling `sratio(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    sratio_result: OutputPathType
    """Result of the sratio operation"""


def sratio(
    value_a: float,
    value_b: float,
    abs_flag: bool = False,
    mask_threshold: float | None = None,
    runner: Runner | None = None,
) -> SratioOutputs:
    """
    Tool to compute ratio A/B if A>B, -B/A if B>A, with options for absolute
    computation and threshold masking.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        value_a: First value for the sratio operation.
        value_b: Second value for the sratio operation.
        abs_flag: Compute absolute value of both A and B before sratio.
        mask_threshold: Threshold based on max(abs(A),abs(B)) > thresh.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SratioOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SRATIO_METADATA)
    cargs = []
    cargs.append("sratio")
    cargs.append(str(value_a))
    cargs.append(str(value_b))
    if abs_flag:
        cargs.append("--abs")
    if mask_threshold is not None:
        cargs.extend([
            "--mask-thresh",
            str(mask_threshold)
        ])
    ret = SratioOutputs(
        root=execution.output_file("."),
        sratio_result=execution.output_file("[SRATIO_RESULT]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SRATIO_METADATA",
    "SratioOutputs",
    "sratio",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1DCAT_METADATA = Metadata(
    id="6497fba75068a5e9c7d3930e26c7a5f42390e7b0.boutiques",
    name="1dcat",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1dcatOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1dcat(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    concatenated_output: OutputPathType
    """Concatenated output in specified format"""


def v_1dcat(
    input_files: list[InputPathType],
    tsv_output: bool = False,
    csv_output: bool = False,
    nonconst_output: bool = False,
    nonfixed_output: bool = False,
    number_format: str | None = None,
    stack_output: bool = False,
    column_row_selection: str | None = None,
    ok_empty: bool = False,
    runner: Runner | None = None,
) -> V1dcatOutputs:
    """
    Concatenates columns of multiple 1D or TSV/CSV files.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_files: Input 1D or TSV/CSV files to concatenate.
        tsv_output: Output in TSV format with tabs as separators and a header\
            line.
        csv_output: Output in CSV format with commas as separators and a header\
            line.
        nonconst_output: Omit columns that are identically constant from the\
            output.
        nonfixed_output: Keep only columns marked as 'free' in the 3dAllineate\
            header.
        number_format: Specify the format of the numbers to be output.
        stack_output: Stack the columns of the resulting matrix in the output.
        column_row_selection: Apply the same column/row selection string to all\
            filenames on the command line.
        ok_empty: Exit quietly when encountering an empty file on disk.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1dcatOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1DCAT_METADATA)
    cargs = []
    cargs.append("1dcat")
    cargs.extend([execution.input_file(f) for f in input_files])
    if tsv_output:
        cargs.append("-tsvout")
    if csv_output:
        cargs.append("-csvout")
    if nonconst_output:
        cargs.append("-nonconst")
    if nonfixed_output:
        cargs.append("-nonfixed")
    if number_format is not None:
        cargs.extend([
            "-form",
            number_format
        ])
    if stack_output:
        cargs.append("-stack")
    if column_row_selection is not None:
        cargs.extend([
            "-sel",
            column_row_selection
        ])
    if ok_empty:
        cargs.append("-OKempty")
    ret = V1dcatOutputs(
        root=execution.output_file("."),
        concatenated_output=execution.output_file("stdout"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1dcatOutputs",
    "V_1DCAT_METADATA",
    "v_1dcat",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_LABEL2LABEL_METADATA = Metadata(
    id="17d5d1cd510c5a4c3d458511bf6609ccc3e1301b.boutiques",
    name="mri_label2label",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriLabel2labelOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_label2label(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_label2label(
    src_label: InputPathType,
    trg_label: str,
    erode: float | None = None,
    open_: float | None = None,
    close: float | None = None,
    dilate: float | None = None,
    ring: float | None = None,
    src_subject: str | None = None,
    trg_subject: str | None = None,
    subject: str | None = None,
    outmask: str | None = None,
    outstat: str | None = None,
    sample: str | None = None,
    regmethod: str | None = None,
    usepathfiles: bool = False,
    hemi: str | None = None,
    src_hemi: str | None = None,
    trg_hemi: str | None = None,
    src_ico_order: float | None = None,
    trg_ico_order: float | None = None,
    direct: str | None = None,
    trgsurf: str | None = None,
    surfreg: str | None = None,
    srcsurfreg: str | None = None,
    trgsurfreg: str | None = None,
    srcsurfreg_file: str | None = None,
    trgsurfreg_file: str | None = None,
    paint: str | None = None,
    dmindmin: str | None = None,
    baryfill: str | None = None,
    label_cortex: str | None = None,
    surf_label2mask: str | None = None,
    srcmask: str | None = None,
    srcmasksign: str | None = None,
    srcmaskframe: float | None = None,
    xfm: str | None = None,
    reg: str | None = None,
    xfm_invert: bool = False,
    projabs: str | None = None,
    projfrac: str | None = None,
    sd: str | None = None,
    nohash: bool = False,
    norevmap: bool = False,
    to_scanner: str | None = None,
    to_tkr: str | None = None,
    scanner: bool = False,
    runner: Runner | None = None,
) -> MriLabel2labelOutputs:
    """
    No description.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        src_label: Input label file.
        trg_label: Output label file.
        erode: Erode the label N times before writing.
        open_: Open the label N times before writing.
        close: Close the label N times before writing.
        dilate: Dilate the label N times before writing.
        ring: Dilate the label N times then remove the original before writing.
        src_subject: Source subject.
        trg_subject: Target subject.
        subject: Use for both target and source.
        outmask: Save output label as a binary mask (surf only).
        outstat: Save output label stat as a mask (surf only).
        sample: Sample label onto surface.
        regmethod: Registration method (surface, volume).
        usepathfiles: Read from and write to a path file.
        hemi: Hemisphere (lh or rh) (with surface).
        src_hemi: Source Hemisphere (lh or rh).
        trg_hemi: Target Hemisphere (lh or rh).
        src_ico_order: When srcsubject=ico.
        trg_ico_order: When trgsubject=ico.
        direct: Use the [xyz] coords for src and trg surfaces to do direct\
            lookup.
        trgsurf: Get xyz from this surface (white).
        surfreg: Surface registration (sphere.reg).
        srcsurfreg: Source surface registration (sphere.reg).
        trgsurfreg: Target surface registration (sphere.reg).
        srcsurfreg_file: Specify full path to source reg.
        trgsurfreg_file: Specify full path to target reg.
        paint: Map to closest vertex on source surfname if d < dmax.
        dmindmin: Bin mask with vertex of closest label point when painting.
        baryfill: Fill with barycentric interpolation.
        label_cortex: Create a label like ?h.cortex.label.
        surf_label2mask: Convert a label to a binary mask.
        srcmask: Source mask surfvalfile thresh <format>.
        srcmasksign: Source mask sign (<abs>, pos, neg).
        srcmaskframe: Source mask frame number (0-based).
        xfm: Use xfm file instead of computing tal xfm.
        reg: Use register.dat file instead of computing tal xfm.
        xfm_invert: Invert xfm, or reg.
        projabs: Project dist mm along surf normal.
        projfrac: Project frac of thickness along surf normal.
        sd: Use specified subjects directory.
        nohash: Don't use hash table when regmethod is surface.
        norevmap: Don't use reverse mapping when regmethod is surface.
        to_scanner: Convert coords to scanner RAS prior to other operations.
        to_tkr: Convert coords to tkregister RAS prior to other operations.
        scanner: Set output coordinate type to scanner.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriLabel2labelOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_LABEL2LABEL_METADATA)
    cargs = []
    cargs.append("mri_label2label")
    cargs.extend([
        "--srclabel",
        execution.input_file(src_label)
    ])
    cargs.extend([
        "--trglabel",
        trg_label
    ])
    if erode is not None:
        cargs.extend([
            "--erode",
            str(erode)
        ])
    if open_ is not None:
        cargs.extend([
            "--open",
            str(open_)
        ])
    if close is not None:
        cargs.extend([
            "--close",
            str(close)
        ])
    if dilate is not None:
        cargs.extend([
            "--dilate",
            str(dilate)
        ])
    if ring is not None:
        cargs.extend([
            "--ring",
            str(ring)
        ])
    if src_subject is not None:
        cargs.extend([
            "--srcsubject",
            src_subject
        ])
    if trg_subject is not None:
        cargs.extend([
            "--trgsubject",
            trg_subject
        ])
    if subject is not None:
        cargs.extend([
            "--s",
            subject
        ])
    if outmask is not None:
        cargs.extend([
            "--outmask",
            outmask
        ])
    if outstat is not None:
        cargs.extend([
            "--outstat",
            outstat
        ])
    if sample is not None:
        cargs.extend([
            "--sample",
            sample
        ])
    if regmethod is not None:
        cargs.extend([
            "--regmethod",
            regmethod
        ])
    if usepathfiles:
        cargs.append("--usepathfiles")
    if hemi is not None:
        cargs.extend([
            "--hemi",
            hemi
        ])
    if src_hemi is not None:
        cargs.extend([
            "--srchemi",
            src_hemi
        ])
    if trg_hemi is not None:
        cargs.extend([
            "--trghemi",
            trg_hemi
        ])
    if src_ico_order is not None:
        cargs.extend([
            "--srcicoorder",
            str(src_ico_order)
        ])
    if trg_ico_order is not None:
        cargs.extend([
            "--trgicoorder",
            str(trg_ico_order)
        ])
    if direct is not None:
        cargs.extend([
            "--direct",
            direct
        ])
    if trgsurf is not None:
        cargs.extend([
            "--trgsurf",
            trgsurf
        ])
    if surfreg is not None:
        cargs.extend([
            "--surfreg",
            surfreg
        ])
    if srcsurfreg is not None:
        cargs.extend([
            "--srcsurfreg",
            srcsurfreg
        ])
    if trgsurfreg is not None:
        cargs.extend([
            "--trgsurfreg",
            trgsurfreg
        ])
    if srcsurfreg_file is not None:
        cargs.extend([
            "--srcsurfreg-file",
            srcsurfreg_file
        ])
    if trgsurfreg_file is not None:
        cargs.extend([
            "--trgsurfreg-file",
            trgsurfreg_file
        ])
    if paint is not None:
        cargs.extend([
            "--paint",
            paint
        ])
    if dmindmin is not None:
        cargs.extend([
            "--dmindmin",
            dmindmin
        ])
    if baryfill is not None:
        cargs.extend([
            "--baryfill",
            baryfill
        ])
    if label_cortex is not None:
        cargs.extend([
            "--label-cortex",
            label_cortex
        ])
    if surf_label2mask is not None:
        cargs.extend([
            "--surf-label2mask",
            surf_label2mask
        ])
    if srcmask is not None:
        cargs.extend([
            "--srcmask",
            srcmask
        ])
    if srcmasksign is not None:
        cargs.extend([
            "--srcmasksign",
            srcmasksign
        ])
    if srcmaskframe is not None:
        cargs.extend([
            "--srcmaskframe",
            str(srcmaskframe)
        ])
    if xfm is not None:
        cargs.extend([
            "--xfm",
            xfm
        ])
    if reg is not None:
        cargs.extend([
            "--reg",
            reg
        ])
    if xfm_invert:
        cargs.append("--xfm-invert")
    if projabs is not None:
        cargs.extend([
            "--projabs",
            projabs
        ])
    if projfrac is not None:
        cargs.extend([
            "--projfrac",
            projfrac
        ])
    if sd is not None:
        cargs.extend([
            "--sd",
            sd
        ])
    if nohash:
        cargs.append("--nohash")
    if norevmap:
        cargs.append("--norevmap")
    if to_scanner is not None:
        cargs.extend([
            "--to-scanner",
            to_scanner
        ])
    if to_tkr is not None:
        cargs.extend([
            "--to-tkr",
            to_tkr
        ])
    if scanner:
        cargs.append("--scanner")
    ret = MriLabel2labelOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_LABEL2LABEL_METADATA",
    "MriLabel2labelOutputs",
    "mri_label2label",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

NIFTI_TOOL_METADATA = Metadata(
    id="3d62871ad5a6df5a56027e145232bf726b83d960.boutiques",
    name="nifti_tool",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class NiftiToolOutputs(typing.NamedTuple):
    """
    Output object returned when calling `nifti_tool(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType | None
    """The nifti file generated as output."""


def nifti_tool(
    action: str,
    input_files: list[InputPathType] | None = None,
    field: str | None = None,
    mod_field: str | None = None,
    prefix: str | None = None,
    debug: float | None = None,
    overwrite: bool = False,
    convert2dtype: str | None = None,
    convert_fail_choice: str | None = None,
    convert_verify: bool = False,
    add_comment_ext: str | None = None,
    rm_ext: str | None = None,
    runner: Runner | None = None,
) -> NiftiToolOutputs:
    """
    Display, modify, or compare nifti headers.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        action: Action type that defines what nifti_tool will do.
        input_files: One or more input nifti files.
        field: Field name to display, modify, or compare.
        mod_field: Field name and new value to modify.
        prefix: Prefix for the output file.
        debug: Debugging level (0-3).
        overwrite: Overwrite input files with modifications.
        convert2dtype: Convert data to a new datatype.
        convert_fail_choice: Action on conversion failure (ignore, warn, fail).
        convert_verify: Verify datatype conversion exactness.
        add_comment_ext: Add COMMENT-type extension to dataset.
        rm_ext: Remove extension by index or ALL.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `NiftiToolOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(NIFTI_TOOL_METADATA)
    cargs = []
    cargs.append("nifti_tool" + action)
    if input_files is not None:
        cargs.extend([
            "-infiles",
            *[execution.input_file(f) for f in input_files]
        ])
    if field is not None:
        cargs.extend([
            "-field",
            field
        ])
    if mod_field is not None:
        cargs.extend([
            "-mod_field",
            mod_field
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if debug is not None:
        cargs.extend([
            "-debug",
            str(debug)
        ])
    if overwrite:
        cargs.append("-overwrite")
    if convert2dtype is not None:
        cargs.extend([
            "-convert2dtype",
            convert2dtype
        ])
    if convert_fail_choice is not None:
        cargs.extend([
            "-convert_fail_choice",
            convert_fail_choice
        ])
    if convert_verify:
        cargs.append("-convert_verify")
    if add_comment_ext is not None:
        cargs.extend([
            "-add_comment_ext",
            add_comment_ext
        ])
    if rm_ext is not None:
        cargs.extend([
            "-rm_ext",
            rm_ext
        ])
    ret = NiftiToolOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(prefix + ".nii") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "NIFTI_TOOL_METADATA",
    "NiftiToolOutputs",
    "nifti_tool",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FS_RUN_FROM_MCR_METADATA = Metadata(
    id="cde2b930dda53cf7f6ac5ac2d3c81e82bcafc347.boutiques",
    name="fs_run_from_mcr",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FsRunFromMcrOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fs_run_from_mcr(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fs_run_from_mcr(
    name: str | None = None,
    command: str | None = None,
    zeroth_flag: bool = False,
    empty_env_flag: bool = False,
    runner: Runner | None = None,
) -> FsRunFromMcrOutputs:
    """
    Replace the shell with the given command.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        name: Pass NAME as the zeroth argument to COMMAND.
        command: The command to execute.
        zeroth_flag: Place a dash in the zeroth argument to COMMAND.
        empty_env_flag: Execute COMMAND with an empty environment.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FsRunFromMcrOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FS_RUN_FROM_MCR_METADATA)
    cargs = []
    cargs.append("fs_run_from_mcr")
    if name is not None:
        cargs.extend([
            "-a",
            name
        ])
    if command is not None:
        cargs.append(command)
    if zeroth_flag:
        cargs.append("-l")
    if empty_env_flag:
        cargs.append("-c")
    ret = FsRunFromMcrOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FS_RUN_FROM_MCR_METADATA",
    "FsRunFromMcrOutputs",
    "fs_run_from_mcr",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DMATMULT_METADATA = Metadata(
    id="71bfcff9d56a1246729006265f95c9743277c4ad.boutiques",
    name="3dmatmult",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dmatmultOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dmatmult(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output dataset from the matrix multiplication"""


def v_3dmatmult(
    input_a: InputPathType,
    input_b: InputPathType,
    prefix: str,
    datum: str | None = None,
    verb: float | None = None,
    runner: Runner | None = None,
) -> V3dmatmultOutputs:
    """
    Multiply AFNI datasets slice-by-slice as matrices.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_a: Specify first (matrix) dataset.
        input_b: Specify second (matrix) dataset.
        prefix: Specify output dataset prefix.
        datum: Specify output data type ('byte', 'short', 'float').
        verb: Specify verbosity level.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dmatmultOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DMATMULT_METADATA)
    cargs = []
    cargs.append("3dmatmult")
    cargs.extend([
        "-inputA",
        execution.input_file(input_a)
    ])
    cargs.extend([
        "-inputB",
        execution.input_file(input_b)
    ])
    cargs.extend([
        "-prefix",
        prefix
    ])
    if datum is not None:
        cargs.extend([
            "-datum",
            datum
        ])
    if verb is not None:
        cargs.extend([
            "-verb",
            str(verb)
        ])
    ret = V3dmatmultOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(prefix),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dmatmultOutputs",
    "V_3DMATMULT_METADATA",
    "v_3dmatmult",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DVOLREG_AFNI_METADATA = Metadata(
    id="80aae3856a13a6dd770babdd60fe4d17ad449c07.boutiques",
    name="3dvolreg.afni",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class V3dvolregAfniOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dvolreg_afni(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    registered_output: OutputPathType
    """Output of the registered dataset"""


def v_3dvolreg_afni(
    input_file: InputPathType,
    output_file: str,
    options: str | None = None,
    runner: Runner | None = None,
) -> V3dvolregAfniOutputs:
    """
    AFNI program for volume registration.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input dataset to be registered.
        output_file: Output dataset with applied registration.
        options: Options for 3dvolreg (consult AFNI documentation for details).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dvolregAfniOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DVOLREG_AFNI_METADATA)
    cargs = []
    cargs.append("3dvolreg.afni")
    cargs.append(execution.input_file(input_file))
    cargs.append(output_file)
    if options is not None:
        cargs.append(options)
    ret = V3dvolregAfniOutputs(
        root=execution.output_file("."),
        registered_output=execution.output_file(output_file + ".nii"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dvolregAfniOutputs",
    "V_3DVOLREG_AFNI_METADATA",
    "v_3dvolreg_afni",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ROBUSTFOV_METADATA = Metadata(
    id="fe07b11b244bac46a02d5373b67ae5b1735d6731.boutiques",
    name="robustfov",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class RobustfovOutputs(typing.NamedTuple):
    """
    Output object returned when calling `robustfov(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_roi_volume: OutputPathType | None
    """ROI volume output"""
    output_matrix_file: OutputPathType | None
    """Matrix output (ROI to full FOV)"""


def robustfov(
    input_file: InputPathType,
    output_image: str | None = "output",
    brain_size: float | None = None,
    matrix_output: str | None = None,
    debug_flag: bool = False,
    verbose_flag: bool = False,
    runner: Runner | None = None,
) -> RobustfovOutputs:
    """
    Reduce FOV of image to remove lower head and neck.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_file: Input image file.
        output_image: ROI volume output name.
        brain_size: Size of the brain in z-dimension (default 170mm).
        matrix_output: Matrix output name (ROI to full FOV).
        debug_flag: Turn on debugging output.
        verbose_flag: Switch on diagnostic messages.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RobustfovOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ROBUSTFOV_METADATA)
    cargs = []
    cargs.append("robustfov")
    cargs.extend([
        "-i",
        execution.input_file(input_file)
    ])
    if output_image is not None:
        cargs.extend([
            "-r",
            output_image
        ])
    if brain_size is not None:
        cargs.extend([
            "-b",
            str(brain_size)
        ])
    if matrix_output is not None:
        cargs.extend([
            "-m",
            matrix_output
        ])
    if debug_flag:
        cargs.append("--debug")
    if verbose_flag:
        cargs.append("--verbose")
    ret = RobustfovOutputs(
        root=execution.output_file("."),
        output_roi_volume=execution.output_file(output_image.removesuffix(".nii.gz") + ".nii.gz") if (output_image is not None) else None,
        output_matrix_file=execution.output_file(matrix_output + ".txt") if (matrix_output is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ROBUSTFOV_METADATA",
    "RobustfovOutputs",
    "robustfov",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

QUANTIFY_BRAINSTEM_STRUCTURES_SH_METADATA = Metadata(
    id="bb094a739a47e09361aec760ca2b87105ebeb041.boutiques",
    name="quantifyBrainstemStructures.sh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class QuantifyBrainstemStructuresShOutputs(typing.NamedTuple):
    """
    Output object returned when calling `quantify_brainstem_structures_sh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    results_file: OutputPathType
    """Output file containing the gathered results."""


def quantify_brainstem_structures_sh(
    output_file: str,
    subjects_directory: str | None = "/usr/local/freesurfer/subjects",
    runner: Runner | None = None,
) -> QuantifyBrainstemStructuresShOutputs:
    """
    A script to gather results from FreeSurfer brainstem processing and write them
    to an output file.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        output_file: The path to the output file where results should be\
            written.
        subjects_directory: The directory containing subject data. Defaults to\
            '/usr/local/freesurfer/subjects' if not provided.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `QuantifyBrainstemStructuresShOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(QUANTIFY_BRAINSTEM_STRUCTURES_SH_METADATA)
    cargs = []
    cargs.append("quantifyBrainstemStructures.sh")
    cargs.append(output_file)
    if subjects_directory is not None:
        cargs.append(subjects_directory)
    ret = QuantifyBrainstemStructuresShOutputs(
        root=execution.output_file("."),
        results_file=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "QUANTIFY_BRAINSTEM_STRUCTURES_SH_METADATA",
    "QuantifyBrainstemStructuresShOutputs",
    "quantify_brainstem_structures_sh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__DJUNCT_4D_IMAGER_METADATA = Metadata(
    id="3dd204eaacbae468c095a2b5730ff8d05c57b1e8.boutiques",
    name="@djunct_4d_imager",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VDjunct4dImagerOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__djunct_4d_imager(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    onescl_png: OutputPathType
    """Output montage image with constant brightness range"""
    sepscl_png: OutputPathType
    """Output montage image with varying brightness range"""
    onescl_mpeg: OutputPathType
    """Output movie with constant brightness range (one slice at a time)"""
    sepscl_mpeg: OutputPathType
    """Output movie with varying brightness range (one slice at a time)"""
    onescl_gif: OutputPathType
    """Output animated GIF with constant brightness range (one slice at a
    time)"""
    sepscl_gif: OutputPathType
    """Output animated GIF with varying brightness range (one slice at a
    time)"""


def v__djunct_4d_imager(
    inset: InputPathType,
    prefix: str,
    do_movie: typing.Literal["MPEG", "AGIF"] | None = None,
    no_clean: bool = False,
    runner: Runner | None = None,
) -> VDjunct4dImagerOutputs:
    """
    The program is useful for viewing the same slice across the 'time' dimension of
    a 4D data set.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        inset: ULay dataset, probably 4D (required).
        prefix: Prefix for output files (required).
        do_movie: Specify type of movie file. Options: MPEG, AGIF.
        no_clean: Keep the final intermediate files.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VDjunct4dImagerOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__DJUNCT_4D_IMAGER_METADATA)
    cargs = []
    cargs.append("@djunct_4d_imager")
    cargs.append(execution.input_file(inset))
    cargs.append(prefix)
    if do_movie is not None:
        cargs.extend([
            "-do_movie",
            do_movie
        ])
    if no_clean:
        cargs.append("-no_clean")
    ret = VDjunct4dImagerOutputs(
        root=execution.output_file("."),
        onescl_png=execution.output_file(prefix + "_onescl.png"),
        sepscl_png=execution.output_file(prefix + "_sepscl.png"),
        onescl_mpeg=execution.output_file(prefix + "_onescl.mpg"),
        sepscl_mpeg=execution.output_file(prefix + "_sepscl.mpg"),
        onescl_gif=execution.output_file(prefix + "_onescl.gif"),
        sepscl_gif=execution.output_file(prefix + "_sepscl.gif"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VDjunct4dImagerOutputs",
    "V__DJUNCT_4D_IMAGER_METADATA",
    "v__djunct_4d_imager",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DMRI_GROUP_METADATA = Metadata(
    id="62e5f1536c9234b5603d09f4124d51072e3633cc.boutiques",
    name="dmri_group",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class DmriGroupOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dmri_group(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def dmri_group(
    input_list: InputPathType,
    reference_volume: InputPathType,
    output_base: str,
    no_interpolation: bool = False,
    sections_num: float | None = None,
    debug_mode: bool = False,
    check_options: bool = False,
    runner: Runner | None = None,
) -> DmriGroupOutputs:
    """
    A tool to process and analyze diffusion MRI group data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_list: Text file with list of individual inputs.
        reference_volume: Reference volume for output path.
        output_base: Base name of output stats files.
        no_interpolation: Do not attempt to interpolate along-tract measures\
            (Assume that subjects are sampled at equivalent positions).
        sections_num: Divide the pathway into a number of sections and output\
            average measures for each section.
        debug_mode: Turn on debugging.
        check_options: Don't run anything, just check options and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DmriGroupOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DMRI_GROUP_METADATA)
    cargs = []
    cargs.append("dmri_group")
    cargs.extend([
        "--list",
        execution.input_file(input_list)
    ])
    cargs.extend([
        "--ref",
        execution.input_file(reference_volume)
    ])
    cargs.extend([
        "--out",
        output_base
    ])
    if no_interpolation:
        cargs.append("--nointerp")
    if sections_num is not None:
        cargs.extend([
            "--sec",
            str(sections_num)
        ])
    if debug_mode:
        cargs.append("--debug")
    if check_options:
        cargs.append("--checkopts")
    ret = DmriGroupOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DMRI_GROUP_METADATA",
    "DmriGroupOutputs",
    "dmri_group",
]
